#
# spec file for package perl-Image-ExifTool
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Image-ExifTool
Name:           perl-Image-ExifTool
Version:        13.24
Release:        1.2
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Read and write meta information
URL:            https://www.exiftool.org/index.html
Source0:        https://www.exiftool.org/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
Recommends:     perl(Archive::Zip)
Recommends:     perl(Compress::Zlib)
Recommends:     perl(Digest::SHA)
Recommends:     perl(IO::Compress::RawDeflate)
Recommends:     perl(IO::Uncompress::RawInflate)
Recommends:     perl(POSIX::strptime)
%{perl_requires}
# MANUAL BEGIN
Requires:       perl(File::RandomAccess) >= 1.11
# MANUAL END

%description
Reads and writes meta information in a wide variety of files, including the
maker notes of many digital cameras by various manufacturers such as Canon,
Casio, DJI, FLIR, FujiFilm, GE, GoPro, HP, JVC/Victor, Kodak, Leaf,
Minolta/Konica-Minolta, Nikon, Nintendo, Olympus/Epson, Panasonic/Leica,
Pentax/Asahi, Phase One, Reconyx, Ricoh, Samsung, Sanyo, Sigma/Foveon and
Sony.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes config_files html README
%exclude %{_bindir}/exiftool
%exclude %{_mandir}/man?/exiftool.?%{?ext_man}
%exclude %{perl_vendorlib}/File/
%exclude %{_mandir}/man?/File::RandomAccess*

%package -n exiftool
Summary:        Customisable application to read and write meta information in files
Group:          Productivity/Graphics/Other
Requires:       perl(Image::ExifTool) = %{version}
Recommends:     perl(Archive::Zip)
# Per https://perldoc.perl.org/index-modules-I.html, these are the part of perl-base.
#Recommends:     perl(Compress::Zlib)
#Recommends:     perl(Digest::MD5)
#Recommends:     perl(Digest::SHA)
#Recommends:     perl(IO::Compress::Bzip2)
#Recommends:     perl(Time::HiRes)

%description -n exiftool
ExifTool is a a full-featured application for reading and writing
meta information in a wide variety of files, including the maker
note information of many digital cameras by various manufacturers
such as Canon, Casio, FujiFilm, GE, HP, JVC/Victor, Kodak, Leaf,
Minolta/Konica-Minolta, Nikon, Olympus/Epson, Panasonic/Leica,
Pentax/Asahi, Reconyx, Ricoh, Samsung, Sanyo, Sigma/Foveon and Sony.

%files -n exiftool
%doc fmt_files/
%doc arg_files/
%{_bindir}/exiftool
%{_mandir}/man?/exiftool.?%{?ext_man}

%package -n perl-File-RandomAccess
Summary:        Random access reads of sequential file or scalar
Group:          Development/Languages/Perl

%description -n perl-File-RandomAccess
Allows random access to sequential file by buffering the file if
necessary. Also allows access to data in memory to be accessed as
if it were a file.

%files -n perl-File-RandomAccess
%{perl_vendorlib}/File/
%{_mandir}/man?/File::RandomAccess*

%changelog
* Sat Mar  8 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.24:
  * Changed -listf, -listr and -listwf options to print descriptions
    when either -v or -l is added (previously only -l did this)
  * Patched to avoid failed PCAP test due to differing time zones (#319)
* Sat Mar  8 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.23:
  * Added read support for CAP, PCAP and PACPNG files
  * Added a number of new Sony LensType2 values
  * Added the 2 new GPSAltitudeRef values defined by EXIF 3.0
  * Decode APP4 "Qualcomm Dual Camera Attributes" metadata
  * EXIF X/YResolution, ResolutionUnit and FlashpixVersion are no
    longer treated as mandatory tags (they were changed to optional
    in the EXIF 3.0 specification)
  * Patched decoding of Nikon Z8 MenuSettings to accommodate changes in
    the data structure as of firmware version 2.1
  * Patched to avoid bug in Perl v5.26.3 which could cause hang when
    reading very large and corrupted XMP
  * Patched -plot option to avoid bug in Google Chrome SVG marker rendering
  * API Changes:
    + Fixed documentation for LargeFileSupport option to reflect current default
* Sat Mar  8 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.22:
  * Improvements and additions to the new plot feature
  * Decode a few more DJI timed metadata tags
  * Extract GainMapImage from PNG images
  * Reverted WebP FileType change of version 13.20
  * Set $^W in the exiftool application to re-enable global warnings (they
    have been disabled since version 12.92 due to the shebang change)
  * Fixed possible incorrect IFD number in "No size tag" warning
  * Fixed "File is empty" error when using -plot with -w to write the
    output file into the same directory as the input files
* Tue Feb 25 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.21:
  * Patched issue that could result in runtime warning for some video files
  * Fixed a bug that could cause a compiler error when using the -plot option
* Tue Feb 25 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.20:
  * Added new -plot option for generating SVG-format plots from tag values
  * Added a new Olympus CameraType
  * Added a new Nikon Z LensID (thanks Warren Hatch)
  * Overhauled decoding of Nikon AF tags (thanks Warren Hatch)
  * Decode timed GPS from yet another model dashcam
  * Decode more information from AAE files
  * Decode more tags from DJI videos
  * Updated Windows launcher (thanks Oliver Betz)
  * Enhanced -w option to be available for use with the -csv output
  * Attempted to patch a problem writing some PDF files
  * Fail if a required module is missing when attempting to write a
    formatted date/time value instead of falling back to write as unformatted
  * Minor change to WebP lossless FileType text
  * API Changes:
    + Added Plot option
* Wed Feb 12 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.19:
  * Added read/write support for PDF and XMP-pdfx SourceModified
  * Decode GPS from two more DJI protobuf formats (Matrice 30 and Mini 4 Pro)
  * Decode timed GPS from Rexing V1-4k dashcam
  * Decode more information from AAE files
  * Made a new icon for the Windows EXE application
  * Changed family 3 groups for ICO files so the first icon is in the Doc1 instead of the Main group
  * Improved handling of ICC_Profile in HEIC images:
    + Profiles for sub-images are extracted as sub-documents
    + Allow only the profile of the main image to be written
  * Updated Sony decoding for ILCE-1M2 (thanks Jos Roost)
* Wed Feb  5 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.18:
  * Decode a number of new GoPro tags
  * Enhanced -geotag option to set Geotime from either SubSecDateTimeOriginal
    (preferentially) or DateTimeOriginal if not otherwise specified
  * Don't allow ICC_Profile to be deleted from QuickTime-based files
    (specifically HEIC, to avoid problem where Apple Preview wouldn't
    display the resulting file)
  * Improved decoding of AF points for Nikon D3400 and D7500
  * Patched issue introduced in 13.13 which could give a "No data reference"
    error when writing MP4 videos from some Google phones
  * Fixed problem writing XMP-iptcExt:LocationCreatedGPSAltitudeRef with
    an incorrect namespace
* Wed Feb  5 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.17:
  * Added support for reading more embedded images and videos written
    in the JPEG trailer by some phones
  * Added support for reading JPEG trailer written by some OnePlus phones
  * Added a -validate warning for QuickTime 'wide' atoms with an invalid size
  * Added a new CanonLensType
  * Avoid decoding Sony 0x9050 data for the ILCE-1M2 because the encoding
    has changed since the ILCE-1 and the new encoding is not yet known (github #310)
  * Fixed issue that could cause runtime warning when using -j with -b
  * Fixed some issues decoding AFPointsUsed for some newer Nikon models
  * Fixed problem corrupting QuickTime-format videos when writing if they
    contain a 'wide' atom with an invalid size
* Tue Jan 28 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.16:
  * Added a couple of new Nikon Z lenses
  * Added a new Canon RFLensType
  * Added support for a MIE trailer on QuickTime-format files
  * Added a number of new EXE MachineType values (github #309)
  * Made "iTunes" a deletable group
  * Updated decoding of many Nikon tags for the Z9 firmware version 5.1
  * Fixed issue where -diff option would miss showing 1 tag from
    a group that exists in the difference file but not in the source file
  * Fixed issue where tag exclusions for alternate files weren't
    honoured in a -p formatting expression when using "$file#:all:all"
    in the expression and the -file#, -x, and -p options all together
  * Fixed FileTypeDescription for lossless extended WebP images
* Tue Jan 28 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.15:
  * Added a few new Panasonic AFSubjectDetection values
  * Added " (lossless)" to FileType for lossless WebP images
  * Avoid treating the QuickTime 'eng' language code as the default
    'und' unless the country code is also the default
  * Fixed issue where writing metadata to a non-extended lossless
    WebP image with an alpha channel could mess up rendering of
    the transparency
  * Fixed problem decoding ID3 WXXX frames (github #307)
* Wed Jan 22 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.14:
  * Fixed bug where ItemList tags weren't created when creating new
    AudioKeys or VideoKeys tags in the same command and neither tag
    group pre-existed in the file
* Wed Jan 22 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.13:
  * Added ability to write tags to the audio/video tracks of MOV/MP4
    videos using the new AudioKeys and VideoKeys group names
  * Added support for another DJI protobuf format (Mavic 3)
  * Decode yet another type of LIGOGPSINFO timed GPS from a dashcam video
  * Extract some proprietary information from JPEG images of Vivo phones
  * Enhanced Geolocation feature to allow the nearest cities to a specified city to be returned
  * Updated xmp2exif.args and exif2xmp.args to properly handle time zones in XMP-exif date/time tags
  * Changed family 1 group names for Keys, ItemList and UserData tags in a track
  * Patched github #306 issue where a torrent file would return a
    format error when reading if it didn't contain an "announce" or "created by" entry
  * Fixed "uninitialized value" runtime warning when reading some EXE files
  * Fixed -diff output to add colon missing from some lines when used with -g
* Mon Jan 13 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.12:
  * Added a few new Panasonic AFAreaMode values
  * Added a couple of new Canon RFLensType values
  * Added a -validate warning for duplicate IPTC tags
  * Decode AF points for some newer Nikon models
  * Decode a new Panasonic tag
  * Decode a couple of previously unknown tags from LIGOGPSINFO records
  * Extract some PDB information if available from Win32 EXE files (github#303)
  * Improved handling of duplicate tags in -diff output
  * Improved handling of QuickTime zero date/time values
  * Enchanced -csv= and -json= options to allow group names and wildcards to be used when specifying which tags
  to import
  * Updated some EXIF:Compression values (github#304)
  * Changed wording of warning when file time couldn't be updated
  * Fixed bug introduced in 13.11 reading EXIF from some EXV files
  * Fixed bug introduced in 12.99 where empty entries in a CSV file weren't ignored as they should be when
  importing with -csv=
  * Fixed problem where MWG module wasn't loaded automatically when specifying Composite:MWG:TAG instead of
  MWG:TAG
  * Fixed bug where -diff option was inconsistent in its treatment of List values when used with the -sep option
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.11:
  * Added warning for an unknown DJI protobuf schema
  * Decode timed GPS from the DJI Osmo Action 5
  * Decode yet another type of LIGOGPSINFO timed GPS from a dashcam video
  * Made Matroska Keywords and Instruments List-type tags
  * Fixed problem were EXIF couldn't be added to some AVIF files
  * API Changes:
    + Added GPSQuadrant option
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.10:
  * Added warnings for out-of-order entries in 'iinf' and 'ipma' boxes of HEIC images
  * Added support for date/time formatting codes %%f and %%z in the inverse print conversion when writing tags
  * Updated Geolocation databases from current geonames.org files
  * Improved verbose output to show values stored with construction method 1 in MP4-based files
  * Enhanced the date/time timezone format specifier %%z so that %%:z returns
    the time zone with a colon separator (eg. "-05:00")
  * Fixed bug where the existing tag wasn't being removed when writing
    a new value for an Unknown QuickTime UserData or ItemList tag
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.09:
  * Added a new QuickTime tag (thanks Matti)
  * Added a missing format check on a few tags when writing
  * Decode a couple of new ICC_Profile tags
  * Patched HEIC writer so newly added XMP or EXIF refers to the 'tmap'
    item as well as the primary item of an HDRGainMap image (since iPhone 15 and 16 do it this way)
  * Fixed compatibility issue where Apple Preview would no
    longer show the gain map image after adding new XMP to an HEIC with an HDR gain map
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.08:
  * Decode ShutterCount for Canon EOS R6 Mark II (thanks Agoston Kapitany)
  * Decode a few new Photoshop tags
  * Suppress all duplicate Warning tags and add count to end of message
  * Changed format of bitmask keys in -listx output
  * Internal streamlining of LIGOGPSINFO decoding
  * Fixed issue where some tags were incorrectly shown as writable in -listx output
  * Fixed incorrect scaling for GPSSpeed in one LIGOGPSINFO variant
  * Fixed an issue with filename encoding when the -L option is used
    and the API WindowsLongPath option is active
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.07:
  * Decode a number of LIGOGPSINFO encrypted and enciphered timed
    GPS types (long overdue, but it took me a couple of years to
    acquire enough sample videos to have a good cross-section of the different formats)
  * Fixed another place where FileSequence could be incremented twice when a -if condition was used
  * Fixed a few places where character 0x7f may not have been escaped in string values
  * API Changes:
    + Changed default WindowsLongPath option back to 1 after adding a
    patch to fix issue with piping from stdin
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.06:
  * Decode timed metadata from MP4 videos of yet another dashcam model
  * Patched issue where FileSequence could increment twice for each
    file when a -if condition was used
  * API Changes:
    + Revert default WindowsLongPath option to the pre-13.05 setting
    until we can solve the pipe problem
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.05:
  * Added a new SonyModelID
  * Added support for XMP HDRGainMap and apdi namespaces
  * Decode DJI timed djmd and dbgi protobuf-format metadata
  * Decode APP10 AROT HDRGainCurve and APP2 URN UniformResourceName
  * Decode a couple of new GoPro tags
  * API Changes:
    + Changed default WindowsLongPath option to 1
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.04:
  * Added the ability to write GPSDOP and GPSMeasureMode from the -geotag
    option if hdop or pdop information exists in the input track file
  * Added a few new Canon RFLensTypes (thanks Norbert Wasser)
  * Decode timed GPS from GoPro Hero 13 videos
  * Improved writing of GPSDestLatitudeRef and GPSDestLongitudeRef tags
    to allow signed numbers to be written in the same way as GPSLatitudeRef and GPSLongitudeRef
  * Warn if using an Image::ExifTool library that doesn't match the application version
  * Renamed an Unknown Photoshop tag
  * Convert GoPro GPSSpeed and GPSSpeed3D from m/s to km/h
  * Patched to tolerate XML header in DOCX xml files
  * Fixed incorrect file offsets for tags in some embedded files of -htmldump output
  * Fixed -htmldump output to show the same names for unknown EXIF tags as with the -u option
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.03:
  * Added ability to include or exclude tags from CSV and JSON
    imports (-csv=CSVFILE and -json=JSONFILE) by adding -TAG or --TAG options
  * Added read/delete support for SEAL[2] metadata in JPG, TIFF, XMP,
    PNG, WEBP, HEIC, PPM, MOV and MP4 files, and read support in PDF, MKV and WAV files
  * Added support for user-defined application extensions in GIF images
  * Added print conversion for QuickTime VideoFullRangeFlag
  * Apply API LimitLongValues option to hex field in -j output
  * Avoid extracting some large AES-encrypted data from PDF files for
    performance reasons unless the -m option is used (current limits
    are 100 kB for XMP and 10 kB for everything else)
  * Fixed WindowsLongPath option to support wide characters (thanks Frank B)
  * Fixed problem writing ICC_Profile to a GIF image which already had one
  * Fixed problem writing Apple:FocusDistanceRange
  * API Changes:
    + Enchanced GlobalTimeShift option to allow the base tag to be
    specified, otherwise use the first specified source date/time tag when copying tags
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.02:
  * Enhanced -j -l output to add optional "fmt" and "hex" fields
  * Enhanced -geotag option to support Android "Export Timeline data" JSON format
  * Changed ProductVersion of Windows launcher to match ExifTool version
  * Patched to use empty group name instead of "Copy0" for family 4
    group name of missing tag when the -f option is used
  * Patched to avoid showing "Unknown" for group of primary tag
    when -g4 or -G4 was used with the -j or -csv option
  * Patched to avoid using Encode module in Windows because it
    can hang if run from a working directory with a long path name
  * Patched to use -csv output if -j also used
  * Fixed a few problems with the new WindowsLongPath option
  * Fixed problem setting FileCreateDate with Xcode 16 command line
    tools if the date/time contains a time zone
  * Fixed problem in -csv output when combined with -g
  * API Changes:
    + Added SaveBin option
* Fri Jan  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 13.01
  * NOTE: Please test the new API WindowsLongPath option because
    the idea is to enable this by default if everything works out well
  * Fixed bug which could result in runtime warning if when API
    IgnoreTags option is set to "all" when reading a TXT file format
  * Fixed problem reading some information from LNK files
  * Fixed verbose output to show "Binary data" message for SCALAR values
  * Fixed bug where part of the hex dump from a -v3 output could
    go to stdout instead of the file specified by a -w option
  * API Changes:
    + Added WindowsLongPath option for testing
    + Changed CharsetFileName option to automatically assume UTF8
    if the file name contains special characters and is valid UTF8
* Wed Oct 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 13.00:
  * Added support for reading GPS from Autel Evo II drone videos
  * Added a new PhaseOne RawFormat value
  * Updated XMP-exifEX tags, exif2xmp.args and xmp2exif.args
    according to the 2024 EXIF for XMP specification
  * Updated Geolocation databases from current geonames.org files
  * Updated the MIME types for a couple of font formats
  * Enhanced -diff option to work with -ec (C-style escape of special chars)
  * Changed name of EXIF Title tag to ImageTitle to correspond with specifiation
  * Reverted a geotag warning message to remove debugging information
    that was added in version 12.67 and moved this information into
    a -v3 verbose message
  * Patched Perl bug which gave "Can't spawn" warning in Windows if
    control-C was pressed while displaying the exiftool application help
  * Fixed API StructFormat JSONQ setting to properly quote values in structures
  * Fixed incorrect AudioStreamType for M2TS videos containing a PGS stream
  * Fixed -diff option so "same tags" messages are only shown
    when -v is added (as per the documentation)
* Sat Oct 19 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.99:
  * Added -diff option to compare the metadata in two files
  * Added a new Canon lens (thanks Norbert Wasser)
  * Decode GPS from 70mai A810 dashcam videos
  * Decode a new QuickTime tag
  * Patched to recognize C2PA APP11 JUMBF header with incorrect
    byte order written by buggy Microsoft software
  * Patched to maintain order of entries in a JSON object when reading
  * Patched to maintain order of CSV columns when setting tags from a CSV file
  * Patched to maintain order of XMP lang-alt entries when writing/copying
  * Fixed typo in an APP12 tag name
  * API Changes:
    + Structured values returned as HASH references with the Struct
    option may contain a new "_ordered_keys_" entry used to
    preserve the order of the entries
    + Added the OrderedKeys method to return the ordered or sorted
    keys from a returned structure value
* Wed Oct  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.98:
  * Added write support for PDF files with huge offsets
  * Added a number of new Sony LensType values
  * Require -v4 or higher to output "JPG RST" lines
  * Patched problem with -fast option when reading HEIC file via a pipe
  * Patched to avoid hang when reading some corrupted XMP
* Thu Sep 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.97:
  * Added ability to ignore up to 4095 bytes of garbage at the end
    of an INDD file with the -m option
  * Added a new Canon RFLensType value
  * Added a new Nikon Z LensID
  * Decode a number of new Nikon Z6_3 tags
  * Decode a few more FujiFilm tags
  * Enhanced %%C format code to allow file-name collisions to be
    avoided by using a colon instead of a decimal in the format modifier
  * Fixed bug which could result in hang when using %%C code in an output file name
* Mon Sep  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.96:
  * More improvements to handling of trailers on video files (and
    add ability to write videos which have an unknown trailer)
  * Fixed problem geotagging from some newer Google Takeout files
* Mon Sep  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.95:
  * Added a couple of new CanonModelID values
  * Decode ColorData for a couple of new Canon models
  * Fixed problem writing video files which have some known trailer types
* Mon Sep  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.94:
  * Added ability to geotag from new-format Google Takeout JSON files
  * Added a few new Android and Xiaomi QuickTime Keys tags
  * Added ability to read C2PA JUMBF metadata from TTF/OTF files
  * Internal changes to code for creating new directories
  * Changed Windows packages to have the application help text file
    in the exiftool_files folder instead of writing it to a temporary directory
  * Removed new QuickTime Keys tags added in 12.93 because these aren't
    used in top-level metadata (written to the video track by Apple devices)
  * Fixed the group names for synthesized default-language QuickTime
    tags and added a verbose message when generating these tags
  * Fixed warning in Geolocation.t self test
* Wed Aug 21 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.93:
  * Added a new Nikon LensID
  * Added a couple of new OpenEXR Compression types
  * Added a couple of new QuickTime Keys tags
  * Decode timed metadata from E-ACE B44 DashCam videos
  * Make "Unrecognized" Samsung Meta warnings minor
  * Fixed bug in -listg6 option which resulted in "uninitialized value" warnings
  * Fixed decoding of Func1Button and Func2Button for the Nikon Z6/Z7
  * Fixed bug reading JUMB metadata from JXL images
* Thu Jul 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.92:
  * Removed -w from exiftool shebang
* Thu Jul 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.91:
  * Fixed 2 test files that were causing failed tests
* Thu Jul 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.90:
  * Added support for reading Samsung trailer from PNG images
  * Decode two more formats of timed GPS from MP4 videos
  * Decode a few more Samung trailer tags (thanks Neal Krawetz)
  * Decode Canon AntiFlicker tag
  * Drop Nikon ShotInfo record when copying MakerNotes from NEF
    to JPG if it is larger than 50000 bytes (then MakerNotes would
    be too large for a single JPEG segment)
  * Changed exiftool shebang from "#!/usr/bin/perl" to "#!/usr/bin/env perl"
  * Revert change of 12.84 to iterate through sub-documents
    with the -p option only if -ee is used
* Mon Jul 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.89:
  * Added new Sony lenses and updated decoding of some tags
  * Minor change to description of NKA files
  * Fixed Archive::Zip problem in Windows executable version
* Fri Jul 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.88:
  * Added ability to read/write deflate-compressed XMP in HEIC files
  * Added a new Canon LensType
  * Added a new XMP-GCamera tag
  * Added a new Nikon LensID
  * Added a few new Canon AFAreaMode values
  * Added config_files/onone.config to the distribution
  * Decode timed accelerometer readings from NextBase 622GW videos
  * Decode Pentax K-3III CameraOrentation
  * Improved German translation for LensModel
  * Enhanced the API StructFormat JSONQ setting to quote all JSON
    values, even if they aren't in a structure
  * Changed -geolocate option so specifying the Keys group writes
    Keys:GPSPosition only if an input city is specified, and
    Keys:LocationName only for input GPS coordinates
  * Tweaked API Geolocation option recognized space-separated lat/lon
    even when there is no decimal point in the numbers
  * API Changes:
  * Changed LargeFileSupport default to 2 and added a warning
    if a large chunk is encountered. Set to 1 to avoid the warning.
* Fri Jun 14 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.87:
  * Added ability to write Google Container XMP tags (using the
    namespace prefix 'GContainer' to avoid conflict with the Google
    Device Container prefix)
  * Decode a few new tags for the Canon EOS R5
  * Decode battery information for the Pentax K-3 III
  * Decode RAFCompression from FujiFilm RAF images
  * Avoid reporting FileSize of 0 for pipes
  * Updated Geolocation databases from current geonames.org files
  * Skip over Matroska Cluster if necessary to read Tags if
    referenced in SeekHead
  * Changed conversion for Matroska SeekID (now in hex with tag
    name in brackets) and SeekPosition (now returns an absolute offset)
  * Fixed problem writing XMP-Device:EarthPos coordinates
  * Fixed typo in a value of Canon:DigitalLensOptimizer
  * Fixed decoding of Matroska VideoScanType
  * Fixed misleading error message when -o option was used to
    write to an unsupported file type
* Tue Jun 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.86:
  * Added a new value for a couple of Olympus tags
  * Improved handling of ID3 user-defined tags
  * Decode all JPEG segments from RICO box in Ricoh MOV videos
  * Decode a few new values for some tags written by Canon EOS R cameras
  * Patched some Olympus WB_RBLevels tags to allow 4 values to
    be written as per some newer models
  * Fixed issue when writing IPTC date tags with a date/time value
    containing subseconds with 4 or more digits
* Wed May 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.85:
  * Added GeolocationFeatureType tag
  * Added read support for Nikon NKA and NXD adjustment files
  * Added a new Apple:ImageCaptureType value, and changed another one
  * Decode a few new Pentax tags
  * Decode a few new Canon tags
  * Decode some Ricoh Exif metadata from MOV videos
  * Extract ID3 UserDefinedText and UserDefinedURL tags by name
  * Make $advFmtSelf available for user-defined helper functions
  * Documented API GeoDir pseudo option feature
  * Tolerate pad byte at end of HIF file when writing
  * Raised priority of FileName, BaseName, Directory and FileType tags
    so they don't get hidden by other tags in the file which may have these names
  * Changed decoding of QuickTime Rotation (irot) to
    correspond with EXIF:Orientation (previously this was oddly
    reported as degrees of counterclockwise rotation)
  * Fixed a typo in the print conversion value for a couple of DPX tags
  * Fixed problem writing some QuickTime tags with very large (> 16 MB) values
  * Fixed bug in build_geolocation utility that resulted in incorrect
    population numbers when run under ActivePerl
* Mon Apr 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.84:
  * Added ability to read speed and accuracy_horizontal when geotagging from OpenTracks GPX files
  * Decode a few more Apple tags and a new CanonVRD tag
  * Enhanced Geolocation option with the ability to return any number of nearby cities
  * Fixed long-standing bug in Windows version that didn't properly handle dates older than 50 years when writing
  FileModifyDate or FileCreateDate
  * Fixed API TimeZone option to work in Windows
  * Fixed problem where the SetTags helper function didn't properly copy tags which have print conversions
  * Fixed problem where a new subregion couldn't be added through a user-defined Geolocation database entry
  * Fixed problem where GeolocFeature option didn't work for some features if a user-generated custom database
  was used
* Mon Apr 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.83:
  * Added SetTags helper function for use in advanced formatting expressions
  * Added a couple of new tags from the DNG 1.7.1 specification
  * Added a new Nikon Z lens
  * Added a couple of new QuickTime tags
  * Added a few more XMP-GCamera tags
  * Added build_geolocation utility to the full distribution
  * Decode a new CanonVRD tag and rename another one
  * Updates to Sony maker note decoding for newer models (thanks Jos Roost)
  * Minor change in -p option to avoid adding the trailing newline if the -b option is also used
  * Minor changes to GM PDR decoding for Gear and angle measurements
  * Removed Geolocation alternate language support from the standard distribution, and added PPLX feature codes
  * Set family 1 group name for NextBase 'nbmt' information to "Nextbase"
  * Fixed incorrect ID of a DNG tag
  * API Changes:
    + Added IgnoreGroups option
* Wed Apr 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.82:
  * Added support for reading GM PDR data from MP4 videos written by
    cars such as Corvettes and Cameros
  * Added support for reading timed GPS from Wolfbox dashcam videos
  * Added "Unknown trailer" to QuickTime warnings originating from
    an unknown trailer
  * Added a new Nikon LensID
  * Extract PreviewImage from Chigee AIO-5 dashcam videos
  * Changed name and print conversion of a recently added FujiFilm tag
  * Only issue "Tag not defined" warnings for the first sub-document
    when using the -p option
  * Fixed a Nikon Z lens name (github #250)
  * Fixed Windows version so -sort works properly with -listgeo
  * API Changes:
    + Added PrintCSV option for optimized extraction of GM PDR data
    in CSV format
* Thu Mar 28 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.81:
  * Added ability to read EXIF and XMP from EXR images
  * Added ability to delete unknown trailer when writing MOV/MP4 videos
  * Added ability to write a couple of Stable Diffusion PNG tags
  * Added ability to write one of the Microsoft Xtra Description tags (#248)
  * Added support for using alternate city names in reverse Geolocation
  * Added support for reading timed GPS from DOD LS600W TS videos
  * Added support for new version of Canon DR4 files
  * Added a number of new iTunesInfo tags
  * Added a new Olympus LensType
  * Allow regular expressions to be used when writing Geolocate tag
  * Decode a number of new Nikon tags (thanks Warren Hatch)
  * Enhanced writing of Geolocate tag to also write Keys:LocationName
  * Cache the results of the last reverse geolocation search to speed
    batch processing when multiple files have the same search parameters
  * Patched problem that could cause runtime errors with some invaid tag names
  * Fixed a couple of newly added FujiFilm tags
  * Fixed decoding of FujiFilm AFAreaZoneSize
  * API Changes:
    + Added GeolocAltNames option
* Wed Mar 20 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.80:
  * Added GeolocationFeatureCode tag
  * Added XMP-acdsee-rs tags and a new XMP-xmpDM tag
  * Added ACDSeeRegion2MWGRegion conversion to config_files/acdsee.config
  * Added GPSAltitudeRef to XMP-iptcExt LocationDetails structure
  * Added a couple of new FujiFilm tags and a new CropMode value
  * Added conversion for XMP-aux:ApproximateFocusDistance "infinity"
  * Improved Geolocation regular expressions to allow negative matches
  * Improved accuracy of Geolocation distance/bearing calculations
  * Changed structure of Geolocation database (now version 1.02)
  * Minor change to key format for user-defined Geolocation name translations
  * Fixed case/spacing of "C2PA" in some CBOR tag descriptions
  * Fixed bug extracting binary data from EXR files
  * API Changes:
    + Added GeolocFeature option
* Mon Mar 18 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.79:
  * Improvements to new Geolocation feature:
    + Added ability to obtain GPS coordinates from city name
    + Added -listgeo option to list the Geolocation database
    + Added the ability to include user-defined cities in the Geolocation database
    + Added the ability to write XMP-iptcExt LocationShown tags using Geolocate feature
    + Added the ability to specify which tags to read from file for the API Geolocation option
    + Added language translations for Geolocation names
    + Increased resolution of Geolocation GPS positions and stored populations
* Wed Mar  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.78:
  * Added new Geolocation feature and write-only Geolocate tag
  * Added new config file entry (@Image::ExifTool::UserDefined::Arguments)
    to allow default command-line arguments to be specified
  * Added print conversion for TIFF-EPStandardID
  * Added ability to delete Nextbase information from MP4 videos
  * Decode timed GPS from MP4 videos written by Nextbase software
  * Decode a number of new tags from Nextbase MP4 videos
  * Decode a few new tags from Garmin MP4 videos
  * Extract PreviewJXL images from DNG 1.7 files
  * Generate Validate, ImageDataHash and UserParam tags earlier to
    allow them to be used in UserDefined Composite tags
  * Enhanced the -c option so a minus sign in the format
    specification prints a signed coordinate without a leading "+"
    for positive numbers
  * Changed formatting of some Accelerometer tags for consistency
  * Changed behaviour of -ee3 option to do a brute-force scan for
    freeGPS in the media data even when referenced by 'gps ' atom
  * Other internal changes to decoding of timed GPS from videos
  * Fixed problem were ExifTool would give up on extracting some
    types of timed GPS from videos after 100 void fixes
  * Fixed bug that could cause runtime error when reading Ogg files
  * Fixed issue where some tags from alternate files using the
  - fileNUM option weren't generated as requested
  * API Changes:
    + Added Geolocation, GeolocMaxDist and GeolocMinPop API options
* Sat Feb 17 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.77:
  * Added new Olympus CameraType and LensType value
  * Added a new Canon Irix LensType
  * Added the ability to delete MacOS XAttrMDItemWhereFroms
  * Decode a few new Canon DPP tags
  * Improved handling of XML-unfriendly characters in JSON field
    names (fixes issue where -X option could produce invalid XML
    when reading JSON with the -struct option)
  * Fixed decoding of ShutterCount for Canon G5X-ii CR3 files
* Thu Feb  1 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.76:
  * Properly implement patch of 12.45 to avoid duplicating raw data
    when writing Sony ARW images where the raw data is double-referenced
    as both strips and tiles
  * Improved handling of bad offsets in HtmlDump output
* Wed Jan 31 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.75:
  * CORRUPTION WARNING: Fixed bug introduced in 12.45 which could
    result in corrupted Sony ARW images from some
    newer models when writing if lossless compression was used
  * Added ability to read C2PA JUMBF metadata from PDF and SVG files
  * Added ability to extract JUMBF metadata as a block
  * Added read support for C2PA (JUMBF-format) files
  * Removed "date before 1970" warning entirely since 64-bit systems
    should be able to handle dates in this range
  * Improved Canon FocusMode decoding
  * Fixed bug introducd in 12.74 which could cause "Undefined
    subroutine" runtime error when reading MIE files
* Wed Jan 24 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.74:
  * Added a couple of new Nikon lenses (thanks Chris)
  * Added write support for a few new QuickTime Keys tags
  * Decode ShutterCount for Canon EOS R5 (thanks John Moyer)
  * Improved error messages in the case of file read errors
  * Enhanced tag name strings (eg. -if option expressions) to allow
    values of multiple matching tags to be concatenated when a group
    name of "All" is specified
  * Enhanced -p option to add -p- feature which avoids adding trailing newline
  * Changed warning from "Shift results in negative time" to "Shift results in date before 1970"
  * Patched calculation of GPSDateTime for the timed metadata in
    Track3 of Garmin videos so the API QuickTimeUTC option is no longer required
  * Fixed conversion error when writing QuickTime:GoogleTrackDuration
  * Fixed misidentification of non-TIFF-format files containing DNGVersion tag
  * Fixed bug where Avoid-ed XMP structures could be created when writing another same-named structure
  * Internal Changes:
    + Changed form of all new() calls to accommodate backward incompatibilities in recent versions of Perl
    + Changed order of InsertTagValues() arguments
    + DateFmt() now returns value of formatted date/time string
* Fri Jan 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 12.73:
  * Added write support for Leica XMP-xmpDSA tags
  * Added read support for timed GPS from Yada RoadCam Pro 4K dashcam videos
  * Added read support for PNG cpIp chunk
  * Added range checks on lat/long values when writing QuickTime:GPSCoordinates
  * Decode a number of new values for Ricoh GR III tags
  * Decode a new Leica tag
  * Improved handling of Brotli compression errors
  * Enhanced API NoWarning option to also apply to app "Warning:" outputs
  * Identify PNG Plus files
  * Changed name of Pentax ISOAutoParameters to ISOAutoMinSpeed and improved decoding
  * Fixed writing of date/time tags in XMP-xmpMM:Pantry structure
  * API Changes:
    + Added LimitLongValues option
* Sat Dec 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 12.72:
  * Added read support for AAC audio files
  * Added a new QuickTime Keys Android tag
  * Added a number of new values for some Ricoh GR III tags
  * Decode timed metadata from Intsa360 Ace Pro MP4 videos
  * Decode GPSDateTime milliseconds in timed Insta360 metadata
  * Decode timed metadata from INNOV K5 TS videos
  * Decode a number of new GoPro timed-metadata tags
  * Decode a few new Xiaomi EXIF tags
  * Fixed writing of JPG/ARW images from some newer Sony models
    to preserve HiddenData
* Fri Dec 22 2023 Michael Vetter <mvetter@suse.com>
- Update to 12.71:
  * Added a warning if there was an error reading an alternate file
    with the -fileNUM option
  * Added the ability to write QuickTime Keys:Encoder
  * Added a few new Canon LensType values
  * Added a new, obscure EXIF tag
  * Decode real-time metadata from Ricoh Theta videos
  * Decode SpecularWhiteLevel for more Canon models (github #232)
  * Decode Canon DualPixelRaw tag
  * Decode a few new Nikon tags
  * Decode more FujiFilm M-RAW tags
  * Improved generation of tag names for some JSON tag ID's containing colons
  * Fixed "Undefined subroutine" error when writing makernotes as a block
  * Fixed missing ID in family 7 group name for ID3 tags which are not valid
    for the specified ID3 version
  * Fixed bug where some tags from alternate files (with the -fileNUM option)
    could show up as "not defined" when used in expressions even though they did exist
  * API Changes:
    + Added NoMandatory option
* Sun Nov 19 2023 Michael Vetter <mvetter@suse.com>
- Update to 12.70:
  * Added ability to read/delete C2PA CAI JUMBF metadata from
    TIFF-based images (eg. DNG), QuickTime-based files
    (eg. MP4) and WebP images, and read JUMBF from other RIFF-based
    files (eg. WAV, AVI), GIF images and ID3v2
  metadata
  * Added read/write support for JPH images
  * Added ability to read Leica Q3 maker notes
  * Added ability to recognize and write FujiFilm M-RAW RAF images
    (multiple raw images in a single file) and the ability to read
    preview-less RAF images
  * Added support for reading a number of obscure Microsoft EXIF tags
  * Added a few new Sony lenses and support for the ILCE-9M3
  * Added a couple of new Panasonic Leica lenses
  * Added a couple of new Canon RF lenses
  * Added a number of new CPUType values for ELF executables
  * Added some new Olympus CameraType values
  * Decode a few more ID3v2.2 tags (github #142)
  * Decode a few new Canon G5X Mark II tags
  * Decode WB_RGGBLevels for a few more Nikon cameras
  * Extract information from FujiFilm M-RAW header
  * Improved decoding of a few Nikon Z tags
  * Marked misspelt XMP-drone-dji:GPSLongtitude tag to Avoid when writing
  * Changed RIFF MaxDataRate conversion to use SI prefixes by default
  * Fixed decoding of unknown ColorBalance information for some Nikon models
  * Fixed an incorrect Nikon Z LensID
  * API Changes:
    + Added ByteUnit option
* Mon Oct 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 12.69:
  * Added support for DNG version 1.7.0.0
  * Added a new XMP-GCamera tag
  * Added a number of new Nikon Z lenses
  * Added a number of new XMP-crs tags
  * Extract XML metadata from some Hasselblad images
  * Tweaked -fast2 option to read metadata from inside mdat atom
    of HEIC images
  * Patched FFF reader to be more tolerant of the mess made by
    incompetent Hasselblad programmers (wrong IFD count for some values)
  * Patched WebP reader to be more tolerant of the mess made by
    incompetent Google programmers (EXIF with wrong header and XMP
    with wrong ID)
  * Fixed problem which could cause "use of uninitialized variable"
    warnings when reading images from some Nikon cameras
  * Fixed List type for new XMP-photomech:CreatorIdentity tag
* Thu Oct 19 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 12.68:
  * Added preliminary read support for XISF images
  * Added the ability to delete JUMBF metadata from PNG images
  * Added support for writing Canon burst-roll CR3 images
  * Added a new Nikon Z9 SubjectDetection value, and improved Zf support (thanks Warren Hatch)
  * Added a couple of new PentaxModelID values
  * Added a few couple of new tag values for the Pentax K-3 Mark III Monochrome (github #226)
  * Added a new XMP-photomech tag
  * Added a new QuickTime ItemList tag
  * Added a new Nikon LensID
  * Added a new Canon LensType
  * Added a new Pentax LensType (thanks dmont)
  * Added a new FujiFilm FilmMode and FaceElementTypes values (thanks Greybeard)
  * Added a few new Canon LensType values (thanks Norbert Wasser)
  * Added conversions for a few Apple:ImageCaptureType values
  * Added new XMP tag for PLUS version 2.0.1
  * Added a new CanonModelID (thanks Laurent Clevy)
  * Support decimal values for FujiFilm ShadowTone and HighlightTone tags
  * Decode some new Sony tags (thanks Jos Roost)
  * Decode ShutterCount for Canon EOS R6 (thanks gamin)
  * Decode QuickTime VideoFullRangeFlag
  * Decode JPGCompression for the Nikon D3S
  * Enhanced -geotag feature to allow writing QuickTime:GPSCoordinates
  * Renamed Panasonic HDRShot tag to MergedImages (forum 15298)
  * Fixed problem where some NEF files were misidentified as NRW
  * Fixed error writing new DataMining tag where URI prefix wasn't being properly added to the value
  * Decode another tag from Canon 1DS raw images (Hubert Figuière, github #219)
  * Decode JPGCompression for newer Nikon models (thanks Warren Hatch)
  * Fixed bug introduced in 12.65 where duplicate tags were not returned even when the groups where specified explicitly
* Fri Aug 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 12.65:
  * Added a new QuickTime Keys tag
  * Added a new CanonModelID
  * Added a new Canon LensType
  * Added number in brackets to converted Samsung MCCData value
  * Decode a number of new Sony tags
  * Decode a few new FlashPix tags (github #217)
  * Improved decoding of Nikon Z9 firmware 4.0 tags
  * Improved parsing of PDF:Keywords to support semicolon-separated lists
  * Enhanced -api option to show list of available options if no argument is provided
  * Lowered priority of IFD1 tags in ARW images so IFD0/SubIFD take precedence
  * Changed QuickTime tag names for atID (AlbumTitleID to ArtistID)
    and plID (PlayListID to AlbumID) (github issue #216), and added cmID (ComposerID)
  * Changed Apple:MediaGroupUUID tag name back to ContentIdentifier
  * Patched the -d option to handle the %%s format code internally when writing (avoids problems due to
    inconsistent behaviour of this format code in the strptime function on different systems)
  * Patched patch of version 12.32 to restore ability to read from named pipes
  * Fixed bug which could cause a hang when processing a corrupt BigTIFF image
  * Fixed document number for auxiliary image metadata in HEIC files
  * Fixed misspelt Apple tag name
  * API Changes:
    + Added AvailableOptions method
* Mon Jul  3 2023 Michael Vetter <mvetter@suse.com>
- Update to 12.64:
  * Added a new Sony LensType (thanks Jos Roost)
  * Added config_files/guano.config to the distribution (thanks StarGeek)
  * Added support for Garmin Low-resolution Video (GLV) files
  * Added JUMBF to the list of deletable groups
  * Added (untested) read support for spherical video tags in Matroska videos
  * Decode a number of new Nikon Z9 tags (thanks Warren Hatch)
  * Decode AmbisonicAudio tags in spherical MP4 vidoes
  * Decode another Apple tag
  * Improved French translations (thanks Philippe Bonnaure of GraphicConverter)
  * Patched to allow writing QuickTime-based videos where the audio/video sample
    description comes after the sample pointers
  * Fixed parsing of GPS from Insta360 videos to properly skip void fixes
  * Fixed problem where Apple iPhone 14 images produced invalid XML in -X
    output when using -struct option
  * API Changes:
    + Added StructFormat option[1] to allow JSON-format serialized structures
    + Added NoDups option to eliminate duplicate items from queued values
    when writing List-type tags
* Mon Jun 12 2023 Gus Kenion <gkenion@suse.com>
- Update to 12.63:
  - Added ability to read/write/create Brotli-compressed metadata
    in JXL images (requires IO::Compress::Brotli)
  - Added partial support for Exif 3.0 specification:
  - Added new EXIF tags
  - Added MPF Original Preservation Image type
  - Support for reading 'utf8' values (but still write only as
    'string')
  - Added support for Adobe HDR Gain Map (hdrgm) XMP tags
  - Added support for reading 7z files (thanks Amir Gooran, github
    [#205]) (but currently this doesn't work for the Windows .exe
    version because I haven't been able to install
    Compress::Raw::Lzma for ActivePerl)
  - Added XMP-panorama tags
  - Added warning if -csv is used with -p
  - Added warning if trying to geotag from a UTF-16 track log
  - Decode ImageWidth/Height from JXL images using partial codestreams
  - Decode more Sony tags for some newer models (thanks Jos Roost)
  - Extract GainMapImage (hrgm box) from JXL files
  - Extract Guano information from WAV files
  - Enhanced ImageDataMD5 feature and renamed to ImageDataHash (with
    ImageDataMD5 alias for backward compatibility)
  - Changed RARVersion tag name to FileVersion
  - Fixed bug introduced in 12.46 which could cause a hang when
    reading a corrupted RIFF-based file
  - Fixed writing of Composition:GPSPosition when -n is used
  - API Changes:
  - Added ImageHashType option
* Thu May  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 12.62:
  - Added basic read support for WPG images
  - Added ImageDataMD5 support for HEIC images
  - Added support for RAR version 5.0 compressed files (thanks Amir Gooran)
  - Added a few new XMP-aux tags (thanks John Ellis)
  - Made Composite tags available for use in -fileNUM argument
  - Better handling of FlashPix VT_EMPTY value
  - Fixed "Can't write" error when specifying a .webp file for the -o option
  - API Changes:
  - Added NoWarning option
  - Added ImageDataMD5 support for J2C and JXL images
  - Added support for PDF 2.0 (specification is finally freely available)
  - Added ability to extract timed Accelerometer data from Azdome GS63H MP4
    videos which don't contain GPS
  - Added some new Sony lenses (thanks Jos Roost)
  - Decode some new tags for the Sony ZV-E1 (thanks Jos Roost)
  - Decode more tags for the Nikon Z30 (thanks Xavier)
  - Enhanced -fileNUM option to allow tags from the main file to be used in the
    file name string
  - Validate sample offset and size when calculating ImageDataMD5 for MP4 videos
    (note: may change ImageDataMD5 value for videos where audio data runs past
    end of media data)
  - Return error when attempting to write a fragmented JXL file
  - Improved robustness for determining image size for corrupted JPEG
  - Patched to allow Insta360 GPS records of unexpected length and tweaked
    verification algorithm to determine validity of these records
  - Fixed bug introduced in 12.57 where -progress:%%f gave runtime warnings
  - Fixed "--" option to ignore subsequent -common_args option
  - Fixed incorrect ImageDataMD5 for Sony A100 ARW images
  - Fixed problem reading new XMP-et:OriginalImageMD5 tag
* Thu Apr  6 2023 Tina Müller <timueller+perl@suse.de>
- updated to 12.60
  see /usr/share/doc/packages/perl-Image-ExifTool/Changes
* Fri Mar 31 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 12.59:
  * COMPATIBILITY WARNING: Changed the calculated ImageDataMD5 for JPEG images
    to include all data from the SOS to the EOI (including the SOS marker but
    not the EOI marker)
  * Added new -fileNUM option to load tags from alternate files
  * Added family 8 groups for accessing tags from alternate files
  * Added new XMP-et:OriginalImageMD5 tag for storing ImageDataMD5 value
  * Added verbose ImageDataMD5 message for JPEG files
  * Added a new Nikon LensID (thanks Warren Hatch)
  * Decode a new Olympus tag and improved decoding of another (thanks Herb)
  * Decode a couple of new PanasonicRaw tags
  * Decode image coordinates for a couple more VNT object types
  * Enhanced ImageDataMD5 to also support MRW, CR3, PNG, MOV/MP4 and RIFF-based
    files
  * Improved verbose messages when deleting NikonApp trailer
  * Patched to avoid structure warnings when copying tags from Nikon files
    containing NKSC metadata
  * Fixed %%-C filename format code to work properly with the -fileOrder and
  - progress options
  * Fixed new ImageDataMD5 tag to work properly with PhaseOne IIQ files
  * Fixed potential ValueConv warning when reading LIF files
  * API Changes:
  - Added SetAlternateFile method
* Tue Mar 21 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 12.58:
  * Added Extra ImageDataMD5 tag to calculate MD5 of image data only
  * Added support for reading DJI APP4 and APP7 JPEG segments
  * Added a new SonyModelID value
  * Decode a few new Nikon tags (thanks Warren Hatch)
  * Patched possible runtime warning when API IgnoreTags option is used to ignore FileType
  * Fixed problem extracting NetName from Windows LNK files
  * Fixed issue where the %%C filename format code would increment the count on an output filename collision, but it is supposed to count the input files
  * Added two new Nikon Z lenses (thanks LibRaw)
  * Added a new Sigma LensType (thanks LibRaw)
  * Added a new Olympus LensType (thanks Herb)
  * Decode more new Nikon tags (thanks Warren Hatch)
  * Decode Photoshop LayerColors, LayerSections and LayerVisible tags
  * Improved Verbose output for QuickTime-format files
  * Set family 1 group name for Garmin GPS from uuid atom
  * Enhanced -progress option to allow message to be displayed every NUM files
  * Significant improvements to parsing of Nikon ShotInfo records for newer models
  * Removed hex dump of APP segments from -v3 output when writing
  * Fixed bug writing negative MIE GPS coordinates
  * Fixed bug where a duplicate XMP could be generated when writing XMP to a JPEG XL image which already contained XMP
  * Fixed problem where HEAD lines may be duplicated in an output file if the -p option was combined with -w+ or -W+
  * Added support for VNT files (both Scene7 Vignette and V-Note document)
  * Added read support for InfiRay IJPEG metadata (thanks Marcos Del Sol Vives)
  * Added some new Sony LensType values (thanks Jos Roost and François Piette)
  * Added a new FujiFilm VideoRecordingMode value (thanks Greybeard)
  * Added two new Canon LensTypes and CanonModelIDs (thanks Norbert Wasser)
  * Added ability to extract semantic images from Apple ProRaw DNG files
  * Added read support for the PNG cICP chunk
  * Decode more Nikon tags (thanks Warren Hatch)
  * Extract PreviewImage from Insta360 trailer record 0x200
  * Extract EmbeddedImageRectangle and some other new tags from VNT files
  * Minor improvement to arg_files/xmp2exif.args (thanks StarGeek)
  * Enhanced -ee option to extract metadata from all frames of a multipart EXR image
  * Removed EXR Layout tag and incorporated into new Flags tag
  * Patched possible hang problem when reading corrupted .rm audio files
  * Added support for geotagging from FlightAware KML files
  * Decode two more types of timed GPS from MOV/MP4 videos (66 types now)
  * Decode a few new Nikon tags (thanks Warren Hatch)
  * Decode a new Samsung HEIC tag
  * Decode FujiFilm RollAngle
  * Fixed bug where the FlatName property wasn't working properly for some user-defined structure tags
* Mon Jan 16 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 12.54:
  - Increased precision of Sony FocusDistance2 conversion
  - Decode a number of new Apple tags (thanks Frank Rupprecht)
  - Fixed bug writing QuickTime-format files which have a zero-sized mdat (ie.
    media data extends to end of file) which would cause an incorrect mdat size
    to be written
  - Added support for a number of new XMP tags written by ACR 15.1
  - Added a new Nikon LensID
  - Decode timed GPS from Lamax S9 dual dashcam MOV videos
  - Decode a number of new Nikon tags (thanks Warren Hatch)
  - Decode a couple of new Canon tags (thanks John Moyer)
  - Decode FujiFilm BWMagentaGreen tag
  - Enable block-write of EXIF to JXL files
  - Accept values of "now" and "Z" when writing EXIF OffsetTime tags
  - Changed priority of XMP when reading/writing HEIC files so that it is no
    longer preferred as with other QuickTime-based formats
  - Changed family 1 group name of Canon DR4 tags from CanonVRD to CanonDR4 to
    allow newer tags to be differentiated from older ones.  The family 0 group
    name for both remains CanonVRD
  - Patched to recognize JXL EXIF box with non-zero header length
  - Patched to avoid runtime error when writing a PDF with an Info dictionary
    which was stored incorrectly as a direct object
  - Fixed problem writing EXIF to JXL images where a new EXIF box was created
    even if one previously existed
* Tue Jan  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 12.52:
  - Added a few new Nikon LensID's (thanks LibRaw and Chris)
  - Added Slovak translations (thanks Peter Bagin)
  - Made SphericalVideoXML readable/writable as a block
  - Improved handling of Matroska metadata tags, including language support
  - Improved French translations (thanks Philippe Bonnaure of GraphicConverter)
  - Improved Composite:GPSAltitude conversion to honour -lang setting
  - Improved -v2 messages to indicate files extracted from zip archives
  - Added a new Olympus LensType (thanks Herb)
  - Extract C2PA JUMBF metadata from PNG images and extract C2PA Salt values
  - Decode NikonSettings for Z9 firmware 3.0 (thanks Warren Hatch)
  - Decode additional camm metadata from Insta360 Pro2 MP4 videos
  - Improved Verbose output when writing Composite tags to add a "+" sign to
    indicate related tags that are being written
  - Enhanced -geotag option CSV format to support GPSImgDirection column
  - Fixed problem where -w+ option didn't work in Windows if there were Unicode
    characters in the path name
  - Fixed problem where only the last image of the sequence was extracted
    (multiple times) when using -ee2 to extract embedded images from FLIR SEQ
    files
  - Fixed issue where GPS reference directions may be unknowingly written when
    using ExifTool 12.44 or later to write GPSLatitude or GPSLongitude without
    specifying a group name.  The fix was to Avoid writing the Composite tags
    unless the Composite group is specified explicitly
  - Fixed -geotag to write orientation and track tags even if some tags in the
    category were missing
  - Fixed inconsistency in selecting which tag to output with the -json option
    when multiple tags with the same JSON key exist and the -TAG# feature is
    used to disable print conversion
  - Fixed problem writing QuickTime:PlayListID
  - Fixed problem writing QuickTime tags when specifying tag ID (ie. family 7
    group) as well as a language code
* Wed Nov  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 12.50:
  * Added a new XMP-GCreations tag
  * Added a few new Sony lenses (thanks Jos Roost)
  * Added new SonyModelID and Olympus CameraType values (thanks LibRaw and Herb)
  * Added a couple of new XMP tags (thanks Jose Oliver-Didier)
  * Added a new Nikon Z lens (thanks LibRaw)
  * Added a new Canon LensType and CanonModelID (thanks Norbert Wasser and
    LibRaw)
  * Added some new Pentax lenses (thanks LibRaw)
  * Added experimental support for timed GPS in TS videos from Jomise T860S-GM
    dashcam (more samples are needed for this to be finalized)
  * Decode information written in "skip" atom of 70mai Pro Plus+ MP4 videos
  * Decode timed accelerometer data from Kenwood dashcam MP4 videos
  * Decode a few new Nikon Z9 tags (thanks Stefan Grussen)
  * Decode ColorData for some newer Canon models (thanks LibRaw)
  * Decode a number of new tags for the Sony ILCE-7RM5 (thanks Jos Roost)
  * Updated IPTC XMP tags to correspond with new Photo Metadata 2022.1 standard
  * Extract JPEG previews from FujiFilm HIF images
  * Changed -if option so multiple -if options are evaluated at the lowest
    specified -fast level
  * Changed MIMEType for ICO and CUR files
  * Enhanced -fast2 so it stops processing QuickTime files at mdat atom
  * Enhanced -listx output so -f also indicates the ID of the parent structure
  for Flattened tags
  * Improved conversion of IPTC date-only and time-only tags to allow formatting
    with the -d option
  * Improved Canon and Nikon TimeZone tags to accept a wider variety of input
    formats when writing
  * Disabled extraction of Nikon Z9 MenuSettings for firmware 3.0 until they can
    be properly decoded (thanks Warren Hatch)
  * Fixed decoding of AF points for some newer Nikon models
  * Fixed inconsistent year and time zone for Kenwood dashcam timed GPS in MP4
    videos
* Fri Sep 30 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 12.45:
  * Added new IPTC Video Metadata version 1.3 tags
  * Added a couple of new Canon lenses (thanks Norbert Wasser)
  * Added a new Sony LensType (thanks Jos Roost)
  * Added known Unknown value for IPTC ChromaticityColorant (thanks Herb)
  * Added new Nikon WhiteBalanceFineTune tag (thanks Milos Komarcevic)
  * Extract the raw thermal data from all frames of a SEQ file when -ee2 is used
  * Decode individual tags in QuickTime ColorRepresentation
  * Decode a new Matroska tag
  * Improved verbose "nothing changed" messages when writing
  * Patched -ee option to extract metadata after the first Cluster in MKV videos
    (previously only -U and -v did this)
  * Patched to differentiate Java bytecode .class files from Mach-O fat binaries
  * Patched to avoid "Use of uninitialized value" warning when deleting GPS
    coordinates via the newly writable Composite tags
  * Patched to avoid duplicating raw data when writing Sony ARW images where the
    raw data is double-referenced as both strips and tiles (affects ARW images
    from some newer models like the ILCE-1 when SonyRawFileType is "Lossless
    Compressed RAW 2")
  * Patched to avoid "fixing" the order of IFD entries in TIFF-based RAW files
    to improve compatibility with some RAW viewers
  * Minor change to Composite FileNumber to remove "-" when -n is used
  * Fixed problem extracting some timed metadata when "-api ignoretags=all" was
    used with "-api requesttags" to request the specific information
  * Fixed -validate feature to avoid incorrectly warning about non-capitalized
    boolean values in XMP
* Mon Jul  4 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 12.42:
  * Added support for reading maker notes from Panasonic DC-GH6 videos
  * Added conversion for Samsung MCCData
  * Added a new Nikon LensID (thanks Chris)
  * Added a few new Canon LensType values
  * Added a couple of new Olympus StackedImage values (thanks Eberhard)
  * Added a few new values for some Nikon Settings tags (thanks Warren Hatch)
  * Added a "lang:" element to the -json output for alternate language tags when -D, -H or -t is used
  * Update DNG writer to not issue an error when writing DNG 1.6 files
  * Decode information from DJI "ae_dbg_info" maker notes
  * Decode Olympus AISubjectTrackingMode
  * Changed ExifTool FileSize print conversion to use kB/MB/GB units instead of KiB/MiB/GiB
  * Changed "is not shiftable" warning to appear in -v (instead of just -v3) output
  * Patched to allow PDF Encrypt object to be "null"
  * Fixed bug reading ICC_Profile 'meta' tags
* Fri Apr 29 2022 Paolo Stivanin <info@paolostivanin.com>
- update to version 12.41:
  * Added support for "OM SYSTEM" maker notes
  * Added 2 new Sony LensType values (thanks Jos Roost)
  * Added some new Canon lenses (thanks LibRaw)
  * Added a new Nikon LensID (thanks Bert Ligtvoet)
  * Added a new Canon ContinuousDrive value (thanks Wolfgang Gulcker)
  * Enhanced -v0 option to also print new file name when renaming, moving or
    copying a file
  * Updated xmp2exif.args and exif2xmp.args helper files to reflect the IPTC
    Photometadata Mapping Guidelines version 2202.1
  * Made "Invalid Xxx data" a minor warning for MakerNote data
  * Patched to allow writing of MP4 videos which have other tracks with a
    missing sample description entry
  * Patched MacOS version to specify directory for external utilities (setfile,
    xattr, stat, mdls and osascript from /usr/bin, and tag from /usr/local/bin)
  * Fixed long-standing problem where Windows version could behave differently
    for -if conditions containing undefined tags
  * Fixed problem where -W+! combined with -j or -X produced invalid JSON or XML
    when  processing multiple files
  * Fixed potential "uninitialized value $time in division" runtime warning when
    reading MP4 videos
  * Added PageCount tag to return the number of pages in a multi-page TIFF
  * Added a new Nikon LensID (thanks Wolfgang Exler)
  * Added a few more Sony LensTypes (thanks Jos Roost)
  * Decode some new Canon tags (thanks Mark Reid)
  * Decode another Nikon Z9 tag (thanks Warren Hatch)
  * Decode Nikon NKSC GPSImgDirection (thanks Olaf)
  * Improved handling of empty XMP structures in lists
  * Tolerate leading UTF-8 BOM in -geotag log files
  * Updated photoshop_paths.config to include WorkingPath
  * Patched to allow writing of MP4 videos which have url tracks with a missing
    sample description entry
  * Fixed deep recursion error when reading multi-page TIFF images with more
    than 100 pages
  * Fixed potential deep recursion runtime error when writing nested XMP
    structures
  * Fixed warning which could be generated when writing new
    Composite:GPSCoordinates tag
  * Fixed description of GPR (General Purpose RAW) file type
  * Fixed typo in the name of a new Nikon tag (thanks Herb)
* Tue Feb  1 2022 Dirk Stoecker <opensuse@dstoecker.de>
- update to version 12.39 - not CPAN released
  For changes in version 12.31 to 12.39 see Changes file
- fixes CVE-2022-23935 security issue
* Fri Sep 17 2021 Dirk Müller <dmueller@suse.com>
- require File::RandomAccess otherwise exiftool(1) won't start
* Mon Aug 23 2021 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 12.30
  see /usr/share/doc/packages/perl-Image-ExifTool/Changes
* Tue Aug  3 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 12.29:
  * Added a few new Nikon and Olympus lenses (thanks LibRaw)
  * Improved a QuickTime "File format error" message to be more
  meaningful, and made it a minor error
  * Changed PNG writer to add EXIF before IDAT
  * Some changes the way JUMBF metadata is handled
  * Patched to read timed GPS from a different type of INSV videos
  * Patched a security issue
  * Fixed problem where ExifTool could hang when processing mebx
  timed metadata
  * Added read support for Leica Image File (LIF) images
  * Added a new Olympus LensType (thanks LibRaw)
  * Decode another Panasonic tag (thanks LibRaw)
  * Decode more timed metadata from Sony MP4 videos
  * Attempt to shorten tag names for metadata in CZI files
  * Allow full QuickTime Keys tag ID's in UserDefined tags
  * Patched to handle special characters in Torrent tag values
  * Added two new Nikon LensID values (thanks Daniel)
  * Added a new Pentax RawDevelopmentProcess value
  * Added a few new Sony LensType values (thanks Jos Roost)
  * Added warning if IPTCDigest is not current
  * Decode a couple more Pentax tags (thanks LibRaw)
  * Decode streaming GPS from Novatek INNOVV MP4 and TS videos
  * Improved tag names in confi_files/covert_regions.config
  * Changed MIME types for MS Office macro-enabled formats
  to add the .12
  * Patched Canon LensID logic to properly identify the
  Canon RF 24-105mm F4 L IS USM lens
  * Patched decoding of camm6 GPSDateTime to use a flexible epoch
  because other apps don't seem to use a consistent time zero
  * Fixed family 7 group names for QuickTime Keys tags
  * Fixed problem reading BeatsPerMinute from some MP4 files
  * Fixed hemisphere problem when extracting GPS from 70mai
  dashcam videos
  * Added support for JPEG Stereo (JPS) images
  * Added a new Sony LensType (thanks LibRaw)
  * Added a new PentaxModelID (thanks LibRaw)
  * Changed ExifTool namespace URI to use exiftool.org
  instead of exiftool.ca in the -X option output (exiftool.ca
  is still recognized when reading XML)
  * Improved handling of large-array warnings in -htmldump output
  * Changed handling of escaped characters in #[CSTR] lines
  of -@ argfile
  * Patched security vulnerability in argument of -lang option
  * Fixed problem which could cause a "Wide character" warning
  and generate a corrupted output file when writing
  some illegal values
* Mon May  3 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 12.25 fixes (boo#1185547)
  * JPEG XL support is now official
  * Added read support for Medical Research Council (MRC) image
    files
  * Added ability to write a number of 3gp tags in video files
  * Added a new Sony PictureProfile value (thanks Jos Roost)
  * Added a new Sony LensType (thanks LibRaw)
  * Added a new Nikon LensID (thanks Niels Kristian Bech Jensen)
  * Added a new Canon LensType
  * Decode more GPS information from Blackvue dashcam videos
  * Decode a couple of new NikonSettings tags (thanks Warren
    Hatch)
  * Decode a few new RIFF tags
  * Improved Validate option to add minor warning if standard
    XMP is missing xpacket wrapper
  * Avoid decoding some large arrays in DNG images to improve
    performance unless the -m option is used
  * Patched bug that could give runtime warning when trying to
    write an empty XMP structure
  * Fixed decoding of ImageWidth/Height for JPEG XL images
  * Fixed problem were Microsoft Xtra tags couldn't be deleted
  version 12.24:
  * Added a new PhaseOne RawFormat value (thanks LibRaw)
  * Decode a new Sony tag (thanks Jos Roost)
  * Decode a few new Panasonic and FujiFilm tags (thanks LibRaw
    and Greybeard)
  * Patched security vulnerability in DjVu reader
  * Updated acdsee.config in distribution (thanks StarGeek)
  * Recognize AutoCAD DXF files
  * More work on experimental JUMBF read support
  * More work on experimental JPEG XL read/write support
  version 12.23:
  * Added support for Olympus ORI files
  * Added experimental read/write support for JPEG XL images
  * Added experimental read support for JUMBF metadata in JPEG
    and Jpeg2000 images
  * Added built-in support for parsing GPS track from Denver
    ACG-8050 videos
    with the -ee option
  * Added a some new Sony lenses (thanks Jos Roost and LibRaw)
  * Changed priority of Samsung trailer tags so the first
    DepthMapImage takes
    precedence when -a is not used
  * Improved identification of M4A audio files
  * Patched to avoid escaping ',' in "Binary data" message when
  - struct is used
  * Removed Unknown flag from MXF VideoCodingSchemeID tag
  * Fixed -forcewrite=EXIF to apply to EXIF in binary header of
    EPS files
  * API Changes:
    + Added BlockExtract option
  version 12.22:
  * Added a few new Sony LensTypes and a new SonyModelID (thanks
    Jos Roost and LibRaw)
  * Added Extra BaseName tag
  * Added a new CanonModelID (thanks LibRaw)
  * Decode timed GPS from unlisted programs in M2TS videos with
    the -ee3 option
  * Decode more Sony rtmd tags
  * Decode some tags for the Sony ILME-FX3 (thanks Jos Roost)
  * Allow negative values to be written to XMP-aux:LensID
  * Recognize HEVC video program in M2TS files
  * Enhanced -b option so --b suppresses tags with binary data
  * Improved flexibility when writing GPS coordinates:
    + Now pulls latitude and longitude from a combined
    GPSCoordinates string
    + Recognizes the full word "South" and "West" to write
    negative coordinates
  * Improved warning when trying to write an integer QuickTime
    date/time tag and Time::Local is not available
  * Convert GPSSpeed from mph to km/h in timed GPS from Garmin
    MP4 videos
  version 12.21:
  * Added a few new iOS QuickTime tags
  * Decode a couple more Sony rtmd tags
  * Patch to avoid possible "Use of uninitialized value" warning
    when attempting to write QuickTime date/time tags with an
    invalid value
  * Fixed problem writing Microsoft Xtra tags
  * Fixed Windows daylight savings time patch for file times
    that was broken in 12.19 (however directory times will not
    yet handle DST properly)
  version 12.20:
  * Added ability to write some Microsoft Xtra tags in MOV/MP4
    videos
  * Added two new Canon LensType values (thanks Norbert Wasser)
  * Added a new Nikon LensID
  * Fixed problem reading FITS comments that start before column
    11
  version 12.19:
  * Added -list_dir option
  * Added the "ls-l" Shortcut tag
  * Extract Comment and History from FITS files
  * Enhanced FilePermissions to include device type (similar to
    "ls -l")
  * Changed the name of Apple ContentIdentifier tag to
    MediaGroupUUID (thanks Neal Krawetz)
  * Fixed a potential "substr outside of string" runtime error
    when reading corrupted EXIF
  * Fixed edge case where NikonScanIFD may not be copied
    properly when copying MakerNotes to another file
  * API Changes:
    + Added ability to read/write System tags of directories
    + Enhanced GetAllGroups() to support family 7 and take
    optional ExifTool reference
    + Changed QuickTimeHandler option default to 1
  version 12.18:
  * Added a new SonyModelID
  * Decode a number of Sony tags for the ILCE-1 (thanks Jos
    Roost)
  * Decode a couple of new Canon tags (thanks LibRaw)
  * Patched to read differently formatted UserData:Keywords as
    written by iPhone
  * Patched to tolerate out-of-order Nikon MakerNote IFD entries
    when obtaining tags necessary for decryption
  * Fixed a few possible Condition warnings for some
    NikonSettings tags
  version 12.17:
  * Added a new Canon FocusMode value
  * Added a new FujiFilm FilmMode value
  * Added a number of new XMP-crs tags (thanks Herb)
  * Decode a new H264 MDPM tag
  * Allow non-conforming lower-case XMP boolean "true" and
    "false" values to be written, but only when print conversion
    is disabled
  * Improved Validate option to warn about non-capitalized
    boolean XMP values
  * Improved logic for setting GPSLatitude/LongitudeRef values
    when writing
  * Changed -json and -php options so the -a option is implied
    even without the -g option
  * Avoid extracting audio/video data from AVI videos when -ee
  - u is used
  * Patched decoding of Canon ContinuousShootingSpeed for newer
    firmware versions of the EOS-1DXmkIII
  * Re-worked LensID patch of version 12.00 (github issue #51)
  * Fixed a few typos in newly-added NikonSettings tags (thanks
    Herb)
  * Fixed problem where group could not be specified for
    PNG-pHYs tags when writing
  version 12.16:
  * Extract another form of video subtitle text
  * Enhanced -ee option with -ee2 and -ee3 to allow parsing of
    the H264 video stream in MP4 files
  * Changed a Nikon FlashMode value
  * Fixed problem that caused a failed DPX test on Strawberry
    Perl
  * API Changes:
    + Enhanced ExtractEmbedded option
  version 12.15:
  * Added a couple of new Sony LensType values (thanks LibRaw
    and Jos Roost)
  * Added a new Nikon FlashMode value (thanks Mike)
  * Decode NikonSettings (thanks Warren Hatch)
  * Decode thermal information from DJI RJPEG images
  * Fixed extra newline in -echo3 and -echo4 outputs added in
    version 12.10
  * Fixed out-of-memory problem when writing some very large PNG
    files under Windows
  version 12.14:
  * Added support for 2 more types of timed GPS in video files
    (that makes 49 different formats now supported)
  * Added validity check for PDF trailer dictionary Size
  * Added a new Pentax LensType
  * Extract metadata from Jpeg2000 Association box
  * Changed -g:XX:YY and -G:XX:YY options to show empty strings
    for non-existent groups
  * Patched to issue warning and avoid writing date/time values
    with a zero month or day number
  * Patched to avoid runtime warnings if trying to set FileName
    to an empty string
  * Fixed issue that could cause GPS test number 12 to fail on
    some systems
  * Fixed problem extracting XML as a block from Jpeg2000
    images, and extract XML tags in the XML group instead of XMP
- Update URL
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 12.13:
  - Add time zone automatically to most string-based QuickTime date/time tags
    when writing unless the PrintConv option is disabled
  - Added -i HIDDEN option to ignore files with names that start with "."
  - Added a few new Nikon ShutterMode values (thanks Jan Skoda)
  - Added ability to write Google GCamera MicroVideo XMP tags
  - Decode a new Sony tag (thanks LibRaw)
  - Changed behaviour when writing only pseudo tags to return an error and avoid
    writing any other tags if writing FileName fails
  - Print "X image files read" message even if only 1 file is read when at least
    one other file has failed the -if condition
  - Added ability to geotag from DJI CSV log files
  - Added a new CanonModelID
  - Added a couple of new Sony LensType values (thanks LibRaw)
  - Enhanced -csvDelim option to allow "\t", "\n", "\r" and "\\"
  - Unescape "\b" and "\f" in imported JSON values
  - Fixed bug introduced in 12.10 which generated a "Not an integer" warning
    when attempting to shift some QuickTime date/time tags
  - Fixed shared-write permission problem with -@ argfile when using -stay_open
    and a filename containing special characters on Windows
  - Added -csvDelim option
  - Added new Canon and Olympus LensType values (thanks LibRaw)
  - Added a warning if ICC_Profile is deleted from an image (github issue #63)
  - EndDir() function for -if option now works when -fileOrder is used
  - Changed FileSize conversion to use binary prefixes since that is how the
    conversion is currently done (eg. MiB instead of MB)
  - Patched -csv option so columns aren't resorted when using -G option and one
    of the tags is missing from a file
  - Fixed incompatiblity with Google Photos when writing UserData:GPSCoordinates
    to MP4 videos
  - Fixed problem where the tags available in a -p format string were limited to
    the same as the -if[NUM] option when NUM was specified
  - Fixed incorrect decoding of SourceFileIndex/SourceDirectoryIndex for Ricoh
    models
* Mon Nov 16 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 12.10
  * Added -validate test for proper TIFF magic number in
    JPEG EXIF header
  * Added support for Nikon Z7 LensData version 0801
  * Added a new XMP-GPano tag
  * Decode ColorData for the Canon EOS 1DXmkIII
  * Decode more tags for the Sony ILCE-7SM3
  * Automatically apply QuickTimeUTC option for CR3 files
  * Improved decoding of XAttrMDLabel from MacOS files
  * Ignore time zones when writing date/time values and
    using the -d option
  * Enhanced -echo3 and -echo4 options to allow exit status
    to be returned
  * Changed -execute so the -q option no longer suppresses
    the "{ready}" message when a synchronization number is used
  * Added ability to copy CanonMakerNotes from CR3 images
    to other file types
  * Added read support for ON1 presets file (.ONP)
  * Added two new CanonModelID values
  * Added trailing "/" when writing QuickTime:GPSCoordinates
  * Added a number of new XMP-crs tags
  * Added a new Sony LensType (thanks Jos Roost)
  * Added a new Nikon Z lens (thanks LibRaw)
  * Added a new Canon LensType
  * Decode ColorData for Canon EOS R5/R6
  * Decode a couple of new HEIF tags
  * Decode FirmwareVersion for Canon M50
  * Improved decoding of Sony CreativeStyle tags
  * Improved parsing of Radiance files to recognize comments
  * Renamed GIF AspectRatio tag to PixelAspectRatio
  * Patched EndDir() feature so subdirectories are always
    processed when -r is used (previously, EndDir() would
    end processing of a directory completely)
  * Avoid loading GoPro module unnecessarily when reading MP4 videos
    from some other cameras
  * Fixed problem with an incorrect naming of CodecID tags in some
    MKV videos
  * Fixed verbose output to avoid "adding" messages for
    existing flattened XMP tags
  * Added a new Sony LensType
  * Recognize Mac OS X xattr files
  * Extract ThumbnailImage from MP4 videos of more dashcam models
  * Improved decoding of a number of Sony tags
  * Fixed problem where the special -if EndDir() function didn't
    work properly for directories after the one in which
    it was initially called
  * Patched to read DLL files which don't have a .rsrc section
  * Patched to support new IGC date format when geotagging
  * Patched to read DLL files with an invalid size in the header
  * Added support for GoPro .360 videos
  * Added some new Canon RF and Nikkor Z lenses
  * Added some new Sony LensType and CreativeStyle values
    and decode some ILCE-7C tags
  * Added a number of new Olympus SceneMode values
  * Added a new Nikon LensID
  * Decode more timed metadata from Insta360 videos
  * Decode timed GPS from videos of more Garmin dashcam models
  * Decode a new GoPro video tag
  * Reformat time-only EventTime values when writing and prevent
    arbitrary strings from being written
  * Patched to accept backslashes in SourceFile entries for -csv option
* Wed Sep 16 2020 Paolo Stivanin <info@paolostivanin.com>
- update to 12.06
  - Added read support for Lyrics3 metadata (and fixed problem
    where APE metadata may be ignored if Lyrics3 exists)
  - Added a new Panasonic VideoBurstMode value
  - Added a new Olympus MultipleExposureMode value
  - Added a new Nikon LensID
  - Added back conversions for XMP-dwc EventTime that were removed
    in 12.04 with a patch to allow time-only values
  - Decode GIF AspectRatio
  - Decode Olympus FocusBracketStepSize
  - Extract PNG iDOT chunk in Binary format with the
    name AppleDataOffsets
  - Process PNG images which do not start with mandatory
    IHDR chunk
  - Added a new Panasonic SelfTimer value
  - Decode a few more DPX tags
  - Extract AIFF APPL tag as ApplicationData
  - Fixed bug writing QuickTime ItemList 'gnre' Genre values
  - Fixed an incorrect value for Panasonic VideoBurstResolution
  - Fixed problem when applying a time shift to some invalid
    makernote date/time values
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 12.04:
  * See /usr/share/doc/packages/perl-Image-ExifTool/Change
* Wed Jun 12 2019 Dirk Stoecker <opensuse@dstoecker.de>
- update to 11.50, see Image-ExifTool-11.50.tar.gz for details
* Wed Mar  6 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 11.30:
  * Add a new Sony/Minolta LensType.
  * Decode streaming metadata from TomTom Bandit Action Cam MP4
    videos.
  * Decode Reconyx HF2 PRO maker notes.
  * Decode ColorData for some new Canon models.
  * Enhanced -geotag feature to set AmbientTemperature if
    available.
  * Remove non-significant spaces from some DICOM values.
  * Fix possible "'x' outside of string" error when reading
    corrupted EXIF.
  * Fix incorrect write group for GeoTIFF tags.
* Sat Mar  2 2019 seanlew@opensuse.org
- Update to version 11.29
  * See /usr/share/doc/packages/perl-Image-ExifTool/Changes
* Mon Feb 18 2019 seanlew@opensuse.org
- Update to version 11.27
  * See /usr/share/doc/packages/perl-Image-ExifTool/Changes
* Fri Jan 11 2019 seanlew@opensuse.org
- Update to version 11.24
  * See /usr/share/doc/packages/perl-Image-ExifTool/Changes
* Fri Sep 28 2018 sor.alexei@meowr.ru
- Update to version 11.11 (changes since 11.01):
  * See /usr/share/doc/packages/perl-Image-ExifTool/Changes
* Tue Jun 12 2018 mvetter@suse.com
- Update to 11.01:
  * Added a new ProfileCMMType
  * Added a Validate warning about non-standard EXIF or XMP in
    PNG images
  * Added a new Canon LensType
  * Decode a couple more PanasonicRaw tags
  * Patched to avoid adding tags to QuickTime videos with multiple
    'mdat' atoms --> avoids potential corruption of these videos!
* Thu Jun  7 2018 mvetter@suse.com
- Update to 11.00:
  * Added read support for WTV and DVR-MS videos
  * Added print conversions for some ASF date/time tags
  * Added a new SonyModelID
  * Decode a new PanasonicRaw tag
  * Decode some new Sony RX100 VI tags
  * Made Padding and OffsetSchema tags "unsafe" so they
    aren't copied by default
* Fri Feb 23 2018 sor.alexei@meowr.ru
- Update to version 10.80 (changes since 10.55):
  * See /usr/share/doc/packages/perl-Image-ExifTool/Changes
* Fri Jun  9 2017 sor.alexei@meowr.ru
- Update to version 10.55 (changes since 10.50):
  * Add a "NoDups" utility function for use in advanced formatting
    expressions.
  * Add a new Pentax LensType.
  * Add some new Pentax DriveMode values.
  * Enhance the -ver option to report Perl include directories with
  - v2.
  * Improve a warning message when advanced formatting expression
    returns undef.
  * A minor change to a few FujiFilm print conversion strings.
  * Change behaviour when interpolating Shortcut tags in a string
    (the values are now separated according to the -sep option
    setting instead of simply being concatenated).
  * Allow file times to be set on systems where futimes is not
    available.
  * Add some new values to a number of FujiFilm tags and change
    some others.
  * Decode a number of new Sony tags for the ILCE-9.
  * Make SonyISO writable.
  * Change behaviour of advanced formatting expression for
    Shortcut tags so it now applies to the combined value rather
    than individual constituent values.
  * Minor changes to some Pentax print conversions.
  * Fix a problem using new NoDups utility with Shortcut tags.
  * Add support for the "MeSa" Photoshop IRB resource.
  * Make XMP-GSpherical tags writable.
  * Improve German translations.
  * Add support for Google XMP GImage and GAudio tags.
  * Add a new Olympus CameraType.
  * Add a two new Sony lenses and decode more ILCE-9 tags.
  * Add new values to some Pentax tags.
  * Add a new Canon LensType.
  * Add an additional checks to the experimental -validate feature.
  * Improve user-defined FileTypes feature to provide more
    flexibility.
  * Enhance the -ext option to allow specific files extensions to
    be processed along with supported files.
  * Add support for GIF multimedia extensions.
  * Add a couple of new Sony/Minolta lenses.
  * Add a new Nikon LensID.
  * Add a new Composite TotalPathPoints tag to
    photoshop_paths.config.
  * Decode a number of new Sony tags and updated some others.
  * Decode a new Pentax tag and fix decoding of another.
  * Update iptcCore.args for new IPTC specification.
  * Change description of a couple of AVI Model tags to match EXIF.
  * Patch tests to avoid failures with Perl 5.25.11 due to missing
    "." in @INC.
  * Fix an incorrect warning from the experimental Validate feature.
  * API Changes:
    + add ListJoin option to replace List and ListSep options.
* Fri Apr 21 2017 sor.alexei@meowr.ru
- Update to version 10.50 (changes since 10.40):
  * Add an experimental metadata validation feature (invoked either
    by requesting the new Extra Validate tag or by setting the
    API Validate option).
  * Add support for the PSDT file extension.
  * Add age.config to the distribution.
  * Add a new Sony lens.
  * Add a new PentaxModelID.
  * Enhance the -p option to allow files to be grouped in sections.
  * Made the makernote offset warning minor.
  * Relaxe parsing of NMEA GGA sentence so comma after the geoid
    units is now optional.
  * Patch the problem extracting value of an unsafe binary tag with
    the -b option when specified using -TAG# instead of -TAG with -n.
  * Add an ability to read/write PNG eXIF and zXIF chunks, and make
    these the place where new EXIF is created in PNG images (zXIF
    if the -z option is used, or eXIF otherwise).
  * Add an ability to copy Photoshop OriginPathInfo with
    photoshop_paths.config.
  * Make FileUserID and FileGroupID writable.
  * Change format for the Sony ImageCount tag.
  * Improvements to the experimental Validate feature.
  * Fix an incorrect XMP swf namespace URI.
  * Fix a problem using new -p section feature when combined with
  - w or -ee.
  * Fix a formatting problem in -listx output when the -lang option
    was used.
  * Fix a problem where UserComment wasn't removed if found in IFD0
    when writing it to the correct IFD.
  * Restrict writing of EXIF:FlashEnergy to a single value as per
    EXIF spec.
  * Revert format change of the Sony ImageCount tag.
  * Change PNG new eXIF/zXIF chunk names to "exIf" and "zxIf" until
    the proposed chunks are accepted (of course, while maintaining
    backward compatibility for reading/updating the other chunks).
  * Lower priority of XMP-pdf:Keywords so it doesn't take
    precedence over PDF:Keywords when the Duplicates option is not
    used.
  * Improve config_files/convert_regions.config to handle the case
    where the RegionInfoMP is missing a Rectangle.
  * Add a few new CanonModelID values and a new Canon LensType.
  * Add two new Nikon lenses.
  * Add a few new Sony/Minolta lenses.
  * Add two new Sony MeteringMode values.
  * Improve verbose dump of Photoshop Layer information.
  * Patch to allow "FileName encoding not specified" warnings to be
    avoided by setting -charset filename="".
  * Fix a problem in photoshop_paths.config printing some paths.
  * Add an ability to write a number of macOS system tags (including
    the file creation date!).
  * Add an ability to extract macOS extended attributes
    ("XAttr" tags).
  * Move macOS System tags from the Extra table into a new macOS
    group and add an ability to extract them by requesting the
    macOS group.
  * Update QuickTime GenreID list.
  * Fix the "Invalid xref" problem when reading some PDF files.
  * Fix an error in Minolta lens list.
  * Fix a minor problem with the -U option generating Unknown tags
    for some known bytes in variable-sized strings.
  * Add read support for JSON-format files.
  * Add two new Sony/Minolta lenses.
  * Add a number of new Pentax tag values.
  * Decode a new Canon CR2 tag.
  * Decode WB information for Canon 800D.
  * Improve config_files/photoshop_paths.config to indicate start
    of paths.
  * Experimental Validate feature no longer warns about Windows XP
    tags.
  * Fix a problem extracting layer information from very large
    PSD/PSB files.
  * Add some new FujiFlashMode values.
  * Add a new Sony LensType.
  * Add a new Canon LensType.
  * Add a new CanonModelID and minor changes to some others.
  * Decode two Pentax tags and add a number of new values for other
    Pentax tags.
  * Decode a new Sony tag.
  * Improvements to the experimental Validate feature.
  * Fix a problem which could cause hang when reading bad PPT
    documents.
  * Add a "DateFmt" utility function for use in advanced formatting
    expressions.
  * Add a new Sony/Minolta LensType.
  * Decode a new Panasonic tag.
  * Fix a problem decoding Sony VariableLowPassFilter values.
  * Fix a problem setting XMP:About when creating new XMP in a file.
  * Fix an incorect Pentax DriveMode value.
  * Decode a new Pentax tag.
  * Improve decoding of Olympus DriveMode.
  * Improve handling of errors from utime when setting file times.
  * Fix a potential hang problem when reading corrupted QuickTime
    metadata.
  * Fix a problem deleting duplicate EXIF tags when writing other
    tags at the same time.
  * API Changes:
    + add an experimental Validate option;
    + add an XAttrTags option;
    + enhance the RequestAll option;
    + enhance the RequestTags option to allow groups to be requested;
    + allow access to the advanced formatting expression via a new ExifTool
    "FMT_EXPR" member variable.
* Tue Feb 14 2017 sor.alexei@meowr.ru
- Update to version 10.40 (changes since 10.36):
  * Decode more information from BMP V4 and V5 images.
  * Add a few new FujiFlashMode values.
  * Change the -geotime default to use an unconverted value of
    DateTimeOriginal.
  * Changed a couple of Sony Voigtlander LensType strings.
  * Warn about invalid tag names used on the command line.
  * Generate a default-language version of QuickTime tags even if
    the same-named tag already exists in an another group.
  * Fix a bug reading some Photoshop layer information.
  * Fix problems in the sample config file time_zone.config.
  * Add a couple of new XMP-ics tags.
  * Add a new Nikon LensID.
  * Decode a couple more PhaseOne tags.
  * Increase priority of Sony 0x0115 WhiteBalance when reading.
  * Range check QuickTime date/time values when writing.
  * Apply CharsetPhotoshop setting to decoding of Photoshop
    LayerNames.
  * Improve identification of Nikon NRW images.
  * Minor improvements to verbose dump of FLIR information.
  * Improvements to the sample time_zone.config file.
  * Remove the trailing null in the -b output for GPSDateStamp.
  * Change the "TAG is not supported" warning when writing to
    "TAG is not defined".
  * Change groups of Composite Preview/Thumbnail/JpgFromRaw/etc
    images to match he tags from which they are derived.
  * Change a description of Composite Nikon LensSpec tag to match
    the tag name.
  * Fix problems reading/writing PreviewImage from some DNG files.
  * Add the Perl version and Unicode settings to -ver -v output.
  * Add a new Sony LensType2 value.
  * Fix a problem with MWG date/time tags.
  * Fix a problem setting the value of a tag from a binary file
    when the PERL_UNICODE environment or the perl -C option is used
    to force UTF-8 treatment of @ARGV elements.
  * Fix tests that were failing on some platforms.
* Tue Jun 14 2016 sor.alexei@meowr.ru
- Update to version 10.36 (changes since 10.20):
  * Add a new Minolta/Sony LensType.
  * Add a new element to the XMP Colorant structure.
  * Add a new Pentax lens.
  * Decode Nikon D5/D500 AF information.
  * Decode a number of new Olympus tags.
  * Decode a number of new Nikon tags.
  * Decode Pentax K-1 AF points.
  * Extract a new DPX tag.
  * Patch to avoid writing an empty structure field for an
    undefined value.
  * Add read support for BPG images.
  * Minor changes to a few of the new Nikon tags.
  * Add read support for Ogg Opus audio files.
  * Add ability to geotag only GPS date/time if no position
    information is available by setting Geotag to 'DATETIMEONLY'
    (all caps).
  * Add a '-charset RIFF' option.
  * Add a new Sony LensType.
  * Decode a number of new Canon tags.
  * Change handling of special characters in RIFF-format files
    (e.g. AVI, WAV).
  * Change MIME type of OGG files to audio/ogg (was audio/x-ogg).
  * Minor change to wording of new Nikon D80 Rotation tag for
    consistency.
  * Add support for DJI Phantom maker notes.
  * Add a few more XMP-crs tags.
  * Add an ability to write DNG OpcodeList tags.
  * Add a new Sony/Minolta LensType.
  * Add a few new FujiFilm Saturation values.
  * Add a new FujiFlashMode value.
  * Fix an incorrect Italian translation.
  * Decode more Pentax tags.
  * Change print conversion of ProcessingTime to show 3 significant
    digits.
  * Fix bug decoding PanasonicRaw DistortionInfo in DNG images.
  * Add a new Pentax PictureMode.
  * Add a new Nikon LensID.
  * Decode a new Samsung tag.
  * Decode a few more Canon tags.
  * Remove an 'Avoid' flag for XMP-crs:ColorTemperature.
  * Change the format of a number of XMP-GPano tags from integer
    to real.
  * Fix incorrect tag ID's for some obscure Island Graphics EXIF
    tags.
  * Fix decoding of some UTF-8 DNG tags which may be stored in BYTE
    format.
  * Add read support for GSpherical metadata in MP4 videos.
  * Add a few new XMP-xmpMM tags and a new XMP-crs tag.
  * Add some new Minolta/Sony lenses.
  * Add two new CanonModelID's.
  * Add two new Canon LensType's.
  * Decode a number of Nikon D610 custom settings.
  * Remove a questionable Samsung tag.
  * Mark TestName tag as 'Unsafe' for writing.
  * Enhance a -progress option with ability to set a console
    window title.
  * Change behaviour of %%C to increment for each processed file as
    documented (was incrementing for each output file created).
  * Patch to recreate XMP in the standard location of PNG images
    when deleting certain non-standard XMP as a group and
    recreating in one step.
  * Fix runtime warning when writing 0 to MinoltaRaw ISOSetting.
  * Fix a problem writing SRW images from some newer Samsung models.
  * Add a new CanonModelID.
  * Add a new Sony LensType.
  * Add a few new NikonLensID's.
  * Add a couple of new Olympus LensType values.
  * Add a new Olympus CameraType.
  * Decode some Canon 80D, 750D, 760D and 1200D CameraInfo tags.
  * Change writing of some ExposureTime and ExposureCompensation
    tags to allow the exact numerator and denominator of the stored
    rational value to be specified.
  * Fix Timecode printout in -v3 output for M2TS videos.
  * Fix some problems with the new '-progress:TITLE'.
  * Fix a problem where '_exiftool_tmp' file could be left around
    after a failed write attempt
  * Fix a potential 'isn't numeric' runtime error when reading a
    PDF file with the -ee option.
  * Add support for new EXIF 2.31 tags.
  * Add some new Canon LensType values.
  * Add a new Olympus LensType.
  * Add the new Sony LensType and SonyModelID.
  * Add a new Pentax LensType.
  * Add fotoware.config and bibble.config files to the distribution.
  * Made Composite SubSecDateTimeOriginal, SubSecCreateDate and
    SubSecModifyDate tags writable, and expanded to include new
    EXIF 2.31 time zone tags.
  * Fix a problem writing user-defined structured tag elements
    with a dot (.) in their tag ID.
  * Add a couple of new Sony LensType values.
  * Decode a few new Sony tags.
  * Decode a few new FLIR tags.
  * Decode some new Nikon D5 tags.
  * Decode a new Apple tag.
  * Enhance -geotag option to allow tagging from KML placemarks
    with a TimeSpan.
  * Enhance the -d option (and an API DateFormat option) to perform
    inverse date/time conversion when writing if the
    POSIX::strptime module is available. If POSIX::strptime is not
    available then the behaviour is like in older versions (i.e.
    the date/time is not converted) unless the API StrictDate
    option is set in which case a warning is issued and the tag is
    not written.
  * Add a read support for FLIF images.
  * Add a couple of new Minolta/Sony LensType values.
  * Add a new SonyModelID.
  * Add a new digiKam XMP tag.
  * Decode a new Apple tag.
  * Decode a few new FujiFilm tags.
  * Decode more Nikon D5 custom settings.
  * Decode a couple more Samsung tags.
  * Improve decoding of the Nikon D500/D5 ShotInfo information.
  * Enhance a -ver option to output system information when -v is
    added.
  * A minor change to parsing of the -@ argfile (comment lines may
    no longer have spaces before the '#').
  * Patch the Jpeg2000 reader to read bad UUID-EXIF boxes.
  * Lower priority of unknown XMP tags when reading.
  * Fix a potential 'Use of uninitialized value' warning when
    decoding compressed a PNG iTXt chunk.
  * Add a write support for FLIF images.
  * Add a support for animated PNG images.
  * Add a few new SamsungModelID values.
  * Add a new Canon LensType.
  * Add a new Sony/Minolta LensType.
  * Decode more Samsung tags.
  * Decode more Nikon tags.
  * Change the 'TAG does not exist' warning when writing to
    'TAG is not supported'.
  * Fix a problem importing information from CSV or JSON databases
    for files with special characters in their name.
  * Time::Piece may now be used as an alternative to
    POSIX::strptime for parsing date/time values when writing.
  * Add a number of new XMP tags.
  * Add a support for a few new Sony cameras.
  * Add a new Nikon LensID.
  * Decode a new Nikon tag.
  * Decode the FLIF encoding type.
  * Decode a new Samsung tag.
  * Ignore a -filter option for a tag if it returns an undefined
    value.
  * Fix an encoding problem with EXIF:Copyright when writing MWG
    tags using an alternate EXIF charset.
  * Add a support for new IPTC Extension version 1.3 + video
    metadata XMP tags.
  * Add a missing print conversion for PreviewDateTime.
  * Decode a few new FujiFilm tags.
  * Enhance MWG date/time tags to support new EXIF time offsets.
  * Patch a loophole in WriteMode which would allow creation of new
    metadata files when creation of new groups was disallowed.
  * Fix a problem where some EXIF date/time tags may not shifted
    when shifting all date/time tags with '-time:all-=VAL' when the
    MWG feature was used.
  * Add 3D Studio MAX files to the list of supported file types.
  * Decode more Sony tags.
  * Decode a couple more FlashPix tags.
  * Minor changes to some of the new IPTC Extension tags.
  * Fix a problem reading some FlashPix (Windows Compound Binary
    Format) files.
  * API Changes:
    + add a CharsetRIFF option.
* Tue Jun 14 2016 sor.alexei@meowr.ru
- Update to version 10.20 (changes since 10.15):
  * Add %%D, %%F and %%E filename format codes.
  * Add a new Minolta lens.
  * Decode Photoshop Compression mode.
  * Decode Nikon MultiExposure information for the D5.
  * Update decoding of Sony tags for ILCA-68.
  * Fix bug adding back XMP tags after deleting all XMP from
    MOV/MP4 files.
  * Fix problem using -o option when reading from stdin (ie. FILE
    is "-").
  * Fix problem where user-defined Composite tags may not always
    override pre-defined Composite tags with the same name, and
    added feature to allow the user to specify whether they should
    override existing tags or not.
  * Add support for Leica X-U (Typ 113) maker notes.
  * Add a new Pentax LensType.
  * Add a number of new Sony lenses.
  * Add a new Canon LensType.
  * Extract TIFF-format thumbnails and previews.
  * Patch to ignore XML entities inside comments.
  * Fix inconsistent conversion of PreviewColorSpace values.
  * Fix writing of TargetPrinter tag.
  * Fix bug introduced in 10.16 which which could cause a runtime
    warning when using the -o option and not writing any "real"
    tags.
  * Add a number of new Sigma LensTypes.
  * Add a few new Sony/Minolta lenses.
  * Add ability to write FilePermissions.
  * Decode NikonCustom settings for the D500.
  * Decode PLUS MediaSummaryCode values.
  * Use hexadecimal for Sigma LensType values.
  * Change -fileOrder option to sort numbers in strings numerically.
  * Fix typo in Samsung lens name.
  * Add a few new Sony and Sigma LensType values.
  * Decode more Nikon tags.
  * Fix an incorrect Sigma LensType.
  * Fix decoding of D500 custom settings for NEF images.
  * Add a few new Sigma LensTypes.
  * Add a new Sony LensType.
  * Add two new Canon LensTypes.
  * Add a couple of new PentaxModelID's.
  * Add a new Pentax LensType.
  * Add a few new Olympus PictureMode values.
  * Add a few more XMP tags.
  * Decode a new Nikon video tag.
  * Patch to allow protected binary data tags to be extracted when
  - b is combined with -php or -X if the tag is specifically
    requested.
  * Fix bug introduced in version 9.96 where extended XMP is
    ignored if the MWG module is used
  * Fix problem where the MWG module wasn't loaded automatically
    if there were MWG tags in the argument to the -p option.
  * Fix column alignment of alternate-language output (requires
    Unicode::GCString to be installed).
  * Fix problem writing Sigma:LensFocalRange.
* Sat Apr 30 2016 sor.alexei@meowr.ru
- Update to version 10.15 (changes since 10.10):
  * Add a couple of new Olympus CameraType values.
  * Add some new ACDSee XMP tags.
  * Add a few more XMP-crs tags.
  * Add a new CanonModelID.
  * Add a couple of new Sony LensType values.
  * Add support for PDF ASCII85Decode filter.
  * Decode a number of new Sony tags.
  * Decode a new Canon tag.
  * Decode a few more Photoshop tags.
  * Convert MDItem date/time values to local time.
  * Patch to read incorrectly written DJI GPSCoordinates in MOV
    videos.
  * Add a new PentaxModelID and SonyModelID.
  * Add a number of new CanonModelID values.
  * Add a new Olypus LensType.
  * Add two new Pentax LensType values.
  * Add a few new Nikon LensID values and updated some others.
  * Add a new Canon LensType.
  * Decode a new Nikon tag.
  * Decode a new CanonCustom tag for the EOS 80D.
  * Improve decoding of SonyRawFileType.
  * Change "Optimised" to "Optimized" in a Photoshop tag value.
  * Fix warning that could be generated by the Canon FileNumber
    conversion.
  * Add a few new Canon LensType values.
  * Add a new CanonModelID.
  * Add a number of new Nikon RetouchHistory modes.
  * Decode a number of new Sony tags.
  * Change a couple of Sigma "| C" lens names for consistency.
  * Add read support for ISO 9660 disk images
  * Add a few new Nikon ISOExpansion values.
  * Add a few new Olympus LensType values.
  * Add a couple of new SonyModelID values.
  * Add a new Olympus CameraType.
  * Add config_files/gps2utm.config to distribution.
  * Decode Canon ColorData for the EOS 80D.
  * Decode a few new Samsung tags.
  * Decode a new Fuji tag.
  * Calculate Duration for APE audio files.
  * Tighten constraints on M2TS file recognition.
  * Improve verbose dump of ID3 information.
  * Change XMP-acdsee:Snapshots to a Binary data tag.
  * Fix bug which prevented writing of various Sony FocalLength
    tags.
  * Add .a and .o to the list of supported file types.
  * Add a few new Sony/Minolta lenses.
  * Decode more Photoshop tags.
  * Decode more information from static library (.a) files.
  * Decode a few more tags from GoPro MP4 videos.
  * Decode ColorData for Canon EOS 1300D.
  * Update Sony decoding for newer models.
  * Fix bug where ScaleFactor35efl could be calculated incorrectly
    for Canon images from some models which have had their EXIF
    rebuilt.
  * API Changes:
    + fix bug which could cause the API Filter option to be
    ignored for some tags when copying tags with the Composite
    option set;
    + fix bug where FileModifyDate wasn't set properly when
    WriteInfo() was called without a destination file name and
    other "real" tags were written at the same time.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to 10.10 (changes since 10.00):
  * Add a new Olympus CameraType.
  * Add a new Canon LensType.
  * Add a few new QuickTime GenreID values.
  * Decode a new Pentax tag.
  * Leica programmers should all be ashamed of the complete shambles
    of metadata they have created.
  * Minor change to the name of a Sigma lens for Canon.
  * Improve recognition of Pentax lens adapter.
  * Rename a few Sony tags and improved decoding of others.
  * Rename a few Pentax tags.
  * Fix problem importing structured information from -X option
    output.
  * Fix round-off errors in value and typo in name of
    CanonVRD:GammaWhitePoint.
  * Fix test failures if Encode, POSIX or Time::Local modules are
    missing.
  * Add ability to read PNG chunks after the normal PNG end of file
    (IEND).
  * Add ability to delete a PNG trailer (with -trailer:all=).
  * Add some new Nikon LensID's.
  * Add a few new Canon LensType's.
  * Add a new Pentax LensType.
  * Decode some new PanasonicRaw tags.
  * Decode a new Pentax tag.
  * Enhance -m option to allow IPTC values which are too short to
    be written.
  * Add support for JPEG 2000 extended-length boxes.
  * Add a few new Canon LensType and CanonModelID values.
  * Add a new Nikon LensID.
  * Add ExifTool version number as a comment in -listx output.
  * Add support for Leica SL (Typ 601) maker notes.
  * Add a new Sony LensType.
  * Decode more Sony tags for some new models.
  * Decode a new Pentax tag.
  * Patch for invalid makernote entry written by
    Sony ILCE-7M2 v1.21.
  * Patch problem reading EXE resources with a missing null
    terminator.
  * Add a few new Microsoft XMP tags.
  * Enhance -r option to allow processing of directory names
    beginning with ".".
  * Avoid writing XMP-microsoft:LensModel unless specified
    explicitly.
  * Limit precision of area size in picasa_faces config file.
  * Move Nikon NCDT GPS tags into the GPS group so they work with
    the Composite GPS tags.
  * Fix problem reading Ricoh RMETA information from some cameras.
  * Add new Canon and Sony LensType values.
  * Add some new Nikon LensID's.
  * Add a new PentaxModelID.
  * Add preliminary support for Motorola maker notes.
  * Change format of XMP-photoshop:DocumentAncestors to write a
    simple Bag of strings rather than structures (since this is
    what the Adobe software writes, contrary to their own XMP
    specification).
  * Fix problem where HASH references may be exposed when copying a
    list of structures to a non-list-type tag.
  * Add a couple of new XMP-digiKam tags.
  * Add a new CanonModelID.
  * Add a new ACDSee XMP tag.
  * Decode a new Canon tag.
  * Improve a few lens names.
  * Patch to remove trailing null when reading improperly written
    QuickTime strings.
  * Fix bug where SystemTags weren't available for use with the -p
    and -if options.
  * Fix problem with warnings on some systems about unimplemented
    functions for FileGroupID and FileUserID when -p or -if were
    used.
  * Add ability to write empty XMP structures.
  * Add write support for PhaseOne MakerNotes tags in IIQ files.
  * Add a new Nikon LensID.
  * Decode a new Olympus tag and improved decoding of DriveMode.
  * Minor improvements to HtmlDump of PhaseOne IIQ and PDF files.
  * Patch to allow overwriting of empty XMP written by some
    PhaseOne cameras.
  * Fix bug in HtmlDump feature that could cause a
    "substr outside of string" error.
  * Add ability to extract OS X system metadata ("MDItem" tags).
  * Add a value conversion for GoogleTrackDuration.
  * Enchance the -i option to allow full path names to be specified.
  * Fix a potential runtime error when writing corrupted JPEG images.
  * Add a new Olympus LensType.
  * Add a couple of new Olympus FlashModel values.
  * Add a new Nikon LensID.
  * Add a new Pentax LensType.
  * Decode a number of new Sony tags.
  * Decode H264:DateTimeOriginal DST flag, and add " DST" to time
    string if set.
  * Decode a few more CanonCustom settings.
  * Fix problem creating user-defined XMP structure elements with
    names containing characters which are illegal in tag names.
  * Improve mechanism for generating tags which must be
    specifically requested when copying or used in -if or -p
    expressions.
  * Patch Composite:FileNumber to handle case where
    Canon:FileNumber is 10000.
  * Patch reading FujiFilm RawImageWidth/Height for new X-Pro2 RAF
    images.
  * Fix problem reading PDF objects which begin with a comment line.
  * Fix problem which could result in ExifTool corrupting a PDF file
    when writing.
  * API Changes:
    + add Filter option;
    + change GetNewValues method name to GetNewValue (GetNewValues
    still works for backward compatibility);
    + change QuickTimeUTC API option to also enforce proper time
    zero;
    + add MDItemTags option;
    + add RequestTags option;
    + no longer generate MDItem tags when RequestAll option is set.
* Tue Aug 18 2015 sor.alexei@meowr.ru
- Update to 10.00 (changes since 9.93):
  * Add Geotag support for Bramor gEO log files.
  * Add support for iCalendar ICS files.
  * Add support for Leica M Monochrom (Type 246) maker notes.
  * Add new "Preview" group for all embedded preview images.
  * Add a new PentaxModelID.
  * Add a new Canon LensType.
  * Add tag name to "Invalid EXIF text encoding" warning.
  * Decode ColorData for Canon EOS 5DS and EOS 5DS R.
  * Change ListItem option so that it also applies when copying
    tags.
  * Enhance FileTypeExtension to return an uppercase extension when
    the print conversion is disabled (eg. the -n option).
  * Fix incorrect FileTypeExtension for virtual device drivers.
  * Fix an improperly formatted warning for duplicate PDF entries.
  * Fix bug creating extended XMP in JPEG images when deleting all
    XMP and adding back in the same step.
  * Add a few new Minolta/Sony lenses.
  * Add config_files/photoshop_paths.config to the full
    distribution.
  * Avoid rebuilding maker notes when using -tagsFromFile with
  - fast2 option.
  * Validate tag names when redirecting (ie. "-DSTTAG<SRCTAG").
  * Add support for CanonVRD version 4 information and DR4 files.
  * Add two new Canon LensType values.
  * Add two new Olympus LensType values.
  * Add a new Minolta/Sony LensType and fixed another one.
  * Add a new Nikon LensID.
  * Add a few new QuickTime tags.
  * Add a new PentaxModelID and a new Pentax PictureMode.
  * Add a few new XMP-aux tags.
  * Decode a couple more DPX tags.
  * Decode NikonCustom tags for D810 firmware version 1.02.
  * Improve -htmlDump output for extended XMP and some other JPEG
    segments.
  * Improve a Canon lens name.
  * Document the -userParam command-line option.
  * Change default behaviour to ignore extended XMP with an
    incorrect GUID (as per the XMP specification).
  * Change the case of a few tag names for consistency.
  * Patch problem with Sony cameras giving incorrect LensInfo for
    some third party lenses, leading to an incorrect LensID by
    ExifTool.
  * Patch problem where GPS minutes or seconds could round up to 60.
  * Fix picasa_faces.config to rotate regions if necessary for RAW
    file types.
  * Add a new Pentax Quality value.
  * Add a new Panasonic AdvancedSceneMode.
  * Minor improvement to lens identification logic based on XMP
    information.
  * Change a few DR4 tag names.
  * Fix improper scoping of XMP namespace prefixes (so conflicting
    prefixes are now properly resolved).
  * Add read support for DSS and DS2 file formats.
  * Add write support for XMP-mwg-rs:Rotation (seen in XMP from
    LR6).
  * Add a new Sigma LensType.
  * Decode Pentax DiffractionCorrection.
  * Decode Olympus ID3 XOLY frame.
  * Decode a few more Sony tags.
  * Improve reliability of decoding Nikon D810 ShotInfo and custom
    settings.
  * Change name of Pentax VignettingCorrection to
    PeripheralIlluminationCorr.
  * Fix problem with user parameters in tag name expressions when
    copying.
  * Add support for the Leica Q (Typ 116) maker notes.
  * Add two new SonyModelID's.
  * Add two new Sony LensType2.
  * Add a new Pentax LensType.
  * Extract a number of new File System tags when SystemTags API
    option is set.
  * Decode a new FujiFilm tag.
  * Decode a number of new Sony tags.
  * Disable writing of XMP to PostScript-format Adobe Illustrator
    files.
  * SourceFile values in -csv and -json input/output are now
    converted to/from filename character set (set by -charset
    filename option) when reading/writing.
  * Rename Flash:FileAttributes to FlashAttributes.
  * Rename FujiFilm:AFPointSet to AFMode and improved decoding.
  * Fix problem where a partial command could be executed if the
  - stay_open option was used and the command is aborted due to an
    error in arguments.
  * Add a few new CanonModelID's.
  * Add a few new Nikon LensID's.
  * Add a new Canon LensType.
  * Decode a number of new Sony tags.
  * Decode a couple more RIFF tags and extract Unknown RIFF tags.
  * Change -b option to avoid splitting PDF List-type tag values.
  * API Changes:
    + add ExtendedXMP option;
    + add SystemTags option;
    + add NoPDFList option.
* Sun Apr 26 2015 sor.alexei@meowr.ru
- Update to 9.93:
  - Add FileTypeExtension tag.
  - Add a few new CanonModelID values.
  - Add a new Olympus CameraType.
  - Add a few new Minolta/Sony lenses.
  - Update arg_files/iptcCore.args for IPTC Extension version 1.2
    tags.
  - Improve VCard parsing/decoding.
  - Improve -fast3 file identification logic.
  - Remove "px" string from SVG ImageWidth/Height tags.
  - Change DOF calculation to use ApproximateFocusDistance.
  - Fix missing FileType for MOI files.
  - Fix potential "Internal Error" bug when writing XMP structures.
* Sun Apr 12 2015 sor.alexei@meowr.ru
- Update to 9.92:
  * Add support for PRISM pmi and prm tags and update to PRISM 3.0.
  * Add read support for Audible .AA files.
  * Add support for Adobe XMP-creatorAtom tags.
  * Add a couple of new XMP-xmpDM tags.
  * Add a new CanonModelID and a new Ricoh WhiteBalance.
  * Add a new Olympus CameraType.
  * Add a new Nikon LensID.
  * Update to XMP PLUS 1.2.1 specification.
  * Enhance DOF calculation to use AverageFocusDistance or
    FocusDistanceUpper/Lower if available.
  * Patch to tolerate different version numbers in XMP namespace
    URI's.
- perl(Archive::Zip) is recommended by exiftool, not required.
* Thu Apr  9 2015 sor.alexei@meowr.ru
- Update to 9.91 (changes since 9.70):
  * Added a couple of mew CanonModelID's
  * Added a couple of new Nikon LensID's
  * Added minor warning when deleting all PDF metadata (because
    it isn't really deleted)
  * Added a new Samsung LensType
  * Added a new Sony/Minolta LensType
  * Decode "Sound & Shot" trailer written by some Samsung Galaxy
    models
  * Decode a number of new Sony tags including FocusDistance2
  * Decode a number of new Canon and Kodak tags
  * Decode a new EXIF tag
  * Decode a few new CanonCustom tags
  * Recognize the JPE file extension
  * Fixed swapped CanonCustom AEMicroadjustment/FEMicroadjustment
    tag names
  * Fixed bug in -listItem option which sometimes prevented it
    from working
  * Fixed interference by -sep option when writing structured tags
  * Added a few new Pentax ISO values
  * Added a new CanonModelID and SonyModelID
  * Added a new Canon LensType
  * Decode AF points for some newer Nikon 1 cameras
  * Improved verbose output for recently decoded Samsung trailer
  * Fixed Samsung trailer writer to properly update offsets in the QDIO block
  * Added a new CanonModelID
  * Added a few new Canon and Sony lenses
  * Delete unknown PNG TextualData tags when deleting all PNG tags
  * Decode AF points for Canon PowerShot G1X Mark II
  * Decode a number of Pentax, Olympus, Panasonic and Sony tags
  * Decode a few more Nikon NCTG tags in MOV videos
  * Decode Nikon D4S custom settings
  * Decode some makernote tags in Sony Xperia Z3 images
  * Make PhotoshopThumbnail and PhotoshopBGRThumbnail writable
    (but "unsafe")
  * Changed order of operations so flattened tags always take
    precedence over structured tags when writing a mix of both
    types of tags
  * Fixed potential bug decoding some Nikon 1 AF points
  * Added a number of new QuickTime GenreID values
  * Added support for some newer Sony cameras
  * Decode more Nikon D4S custom settings
  * Improved lens identification logic for XMP metadata
  * Fixed typo in Condition for a few D3 NikonCustom tags
  * Fixed bug which could cause a "Use of uninitialized value $val"
    runtime error when reading XML
  * Added support for FLIR version 101 metadata
  * Added a new Olympus LensType
  * Added a new Pentax LensType
  * Added a new Samsung LensType
  * Decode a few more Nikon D4S tags
  * Decode a few more Sony tags
  * Decode a new FujiFilm tag
  * Improved formula for calculating Sony:FocusDistance2
  * Changed XMP parsing to impose standard namespace prefixes,
    thus avoiding (some) problems reading the ugly XMP generated
    by Microsoft products
  * Fixed decoding of Nikon FileInfo tags for recent DSLR models
  * Added support for the LFR format (same as LFP)
  * Added support for Samsung models which write 2 values for
    LensType
  * Added a new Samsung LensType
  * Added a few new Nikon LensID's
  * Added a new PentaxModelID
  * Added some new Olympus WhiteBalance2 values
  * Added a new EXIF:Compression value
  * Decode a new FujiFilm tag
  * Decode a few more private TIFF tags
  * Improved warning message if "DIR" or "FILE" is used literally
    on the command line
  * Improved "-j -b" output to encode any non-UTF8 values as
    Base64
  * Enhanced -fast option (FastScan API option) to allow file
    processing to be bypassed entirely
  * Changed conversions for a couple of Nikon 1 AF tags for
    consistency
  * Changed reported FileType for LNK, KEY, KTH, NUMBERS,
    NMBTEMPLATE and PAGES files to match extension
  * Fixed problems adding new XMP and deleting old XMP from MP4
    videos
  * Fixed problem writing FileModifyDate/FileCreateDate when
  - overwrite_original_in_place is used
  * Added FilePath tag (generated only if specified and Cwd is
    available)
  * Added a new Panasonic ShootingMode
  * Added a new FujiFilm WhiteBalance value
  * Added a new QuickTime vendor ID
  * Added a new Pentax RawDevelopmentProcess value
  * Decode a few new QuickTime tags
  * Decode some new tags in Kodak SP360 MP4 videos
  * Fixed bug that could cause a runtime error when parsing a
    Canon EOS 40D image which had been edited by Nikon Capture
  * Fixed bug which could produce invalid XML in the -X output when
  - struct was also used
  * Added a new Nikon LensID and a new Canon LensType
  * Decode a new unknown atom in Canon MOV videos
  * Decode a number of new Sony tags
  * Decode a number of new Samsung tags
  * Improved MakerNote compatibility when writing by adding the
    same amount of padding after the MakerNote IFD as that written
    by the specific camera model
  * Changed the DNG BaselineExposureOffset to a signed rational
    (contrary to the DNG 1.4 specification, which specifies an
    unsigned RATIONAL, but obviously Adobe meant for it to store
    negative values)
  * Changed name of new QuickTime Rating tag to RatingPercent
  * Fixed problem introduced in 9.64 where multiple list values
    from some tags in ZIP-based files were extracted as separate
    tags instead of as a list when the -struct option was used,
    and implemented a different patch to just suppress the
    structure warnings without changing the 9.63 behaviour
  * Fixed problem where some EXIF information in MOV videos could
    be corrupted when writing
  * Added read support for MOI files
  * Added a few more Canon LensType's
  * Added a new Nikon LensID
  * Added a couple of new Panasonic ImageQuality values
  * Decode a new FujiFilm tag and added a new FilmMode value
  * Allow zero-length group names to be specified (which provides a
    method to directly access the 0th copy of a duplicate tag using
    the empty family 4 group name by specifying "4:TAG")
  * Fixed invalid Samsung tag name
  * Fixed writing of XMP:ExposureCompensation with fractional
    values
  * Added a few new Canon and Minolta/Sony LensType values
  * Added a few new CanonModelID's
  * Decode a few new Canon tags
  * Suppress warning for Canon 7DmkIII VignettingCorrUnknown2 data
    format
  * Fixed runtime warning when piping an MOI file to exiftool
  * Added Composite:Megapixels tag
  * Added a few new Nikon LensID's
  * Decode a number of new Sony tags
  * Improved Polish translations
  * Changed exif2xmp.args and xmp2exif.args files (available in the
    full ExifTool distribution) to avoid using non-standard XMP
    namespaces
  * Added support for new IPTC Extension version 1.2 XMP tags
  * Added support for Leica X (Typ 113) maker notes
  * Added read support for ChartTIFF tags
  * Added a few new Canon LensType values
  * Added a few new Nikon LensID's
  * Added a number of new Olympus ArtFilterEffect values
  * Added some new Olympus AspectRatio values
  * Added a new PentaxModelID
  * Added a new Olympus CameraType
  * Added new values for various Canon tags
  * Decode a number of new Sony tags
  * Decode a couple more Nikon ShootingMode bits
  * Updated to Nov 2014 XMP specification
  * Added a new CanonModelID
  * Added a new Pentax LensType and PentaxModelID
  * Added support for Sigma X3F version 4.1 images
  * Added a number of new Sigma LensType values
  * Added a new Canon LensType
  * Added a new Leica LensType
  * Added a new Olympus CameraType
  * Decode a couple more FujiFilm RAF tags
  * Changed names of and properly decode new Olympus Pitch/Roll tags
  * Changed rounding method for rational values in an attempt to
    fix failed tests on FreeBSD 10.1 and Perl 5.20.1 with
    uselongdouble enabled
  * Resolved issue with duplicate SamsungModelID values
  * Added a number of new Sigma LensType values
  * Fixed problem extracting some Microsoft tags from MP4/MOV videos
  * Decode a few more ID3 tags
  * Improved decoding of some Pentax tags
  * Extended -list and -listw options to include flattened tags
  * Patched to recognize ID3v2.3 tags in ID3v2.4 metadata and visa
    versa
  * Patched byte ordering problems with Nikon FileInfo tags for the
    D5500
  * Fixed bug where other groups were ignored when multiple groups
    were specified when writing and one of those groups was a
    specific EXIF IFD (eg. -ExifIFD:Time:all= ignored the Time
    constraint)
  * Added some new Minolta/Sony LensType values
  * Added config_files/picasa_faces.config to the distribution
  * Added a few new Minolta/Sony and Nikon lenses
  * Added new Canon and Sigma lenses
  * Decode Nikon D810 custom settings
  * Decode a few new Nikon tags
  * Fixed problem reading multi-valued Microsoft Xtra tags
  * Added read support for VCard files
  * Added support for AAX files
  * Added --sort option
  * Added a number of new QuickTime GenreID values
  * Added new Canon, Nikon, Olympus and Samsung lenses
  * Added a new Olympus CameraType
  * Added a new Sony FlashMode value
  * Decode a new Apple makernote tag
  * Decode a number of new QuickTime tags found in Audible audio
    books
  * Improved the naming of a FujiFilm tag
  * Removed "not yet tested" warning when writing FujiFilm RAF
    version 0200
  * Renamed distribution file config_files/ExifTool_config to
    example.config
  * Increased maximum metadata atom size for QuickTime files and
    added warning if an atom is larger than the limit
  * Changed writing of filesystem date/time tags to override the
  - P option
  * API Changes:
    + Added ListItem option
    + Added CharsetFileName option
    + Added UserParam option
- Do not obsolete exiftool package within exiftool package.
- Change homepage to project homepage.
- Simplify %%files.
- Spec cleanup.
* Tue Sep  9 2014 Greg.Freemyer@gmail.com
  Update to Version 9.70 (production release)
  - Improved verbose dump for LFP images
  - Patched to repair incorrect list types in XMP structures when writing
  - Patched to avoid MPEG Layer 3 check for files with a "MUS" extension
  - Fixed incorrect behaviour of -addTagsFromFile when adding list items from
    multiple variable-named source files
  July 27, 2014 - Version 9.69
  - Added ability to write PNG PhysicalPixel (PNG-pHYs) tags
  - Added minor warning when creating EXIF or IPTC in PNG images
  - API Changes:
  - Shift.pl now autoloads when ShiftTime() is called
  - The 3rd argument to ShiftTime() is now optional
  July 19, 2014 - Version 9.68
  - Added read support for Lytro LFP files
  - Allow Composite tag to have no Require'd or Desire'd tags
  - Improved -geotag verbose output
  - Changed so XMP tags take priority when reading QuickTime-format files
  - Changed PSD file description to "Photoshop Document"
  - Fixed problem where -geotag option could fail if -v4 was used
  - Fixed problem writing SonyDateTime2
  July 6, 2014 - Version 9.67
  - Fixed inaccuracies in decoding some SigmaRaw tags from the X3F header
  July 1, 2014 - Version 9.66
  - Swap "GPS track start/end" labels in -geotag -v2 output if track is stored
    in reverse chronological order
  - Changed handling of IPTC groups so that standard IPTC always has a family 1
    group name of "IPTC", and takes priority over non-standard IPTC when
    duplicates are not allowed
  - Fixed problem parsing some NMEA sentences, and added support for GPZDA
  June 20, 2014 - Version 9.65
  - Added a print conversion for Unknown ICC_Profile MeasurementGeometry
  - Added LargeTags shortcut
  - Avoid loading data for some tags with large binary data values if they were
    specifically excluded by the command
  - Patched potential "subscript -1" runtime error when reading EPS files
  June 14, 2014 - Version 9.64
  - Added write-only TestName tag for dry-run tests of file renaming feature
  - Patched to avoid structure warnings when copying tags from ZIP-based files
  - Fixed problem using advanced formatting feature in a -if condition
  - Fixed problem parsing Canon VignettingCorr for some newer PowerShot models
  - API Changes:
  - Added 'Test' option to SetFileName()
  May 31, 2014 - Version 9.63
  - Added ability to combine -lang option with -listx to extract only one language
  - Remove leading XML comment from XMP if it exists when writing as a block
  - Another attempt to patch problem obtaining a consistent "full path" for
    source files when importing a CSV database in Windows
  May 24, 2014 - Version 9.62
  - Added message about SourceFile names to -v2 output when importing a database
    with -csv= or -json=
  - Changed -n option for GPSTimeStamp to return nanosecond precision
  May 18, 2014 - Version 9.61
  - Added ability to combine -l with -listf, -listr or -listwf to add
    descriptions of the file type
  - Fixed quirk where ExifTool could incorrectly report that a file was changed
    when conditionally deleting a non-existent tag as a block
  .... see Changes for more, especially all device specific release notes
* Fri Mar  7 2014 coolo@suse.com
- updated to 9.53
  - Added user-defined file types feature
  - Added support for a few more XMP-expressionmedia tags
  - Decode CameraTemperature from a few new Canon models
  - Decode another Sony tag (thanks Jos Roost)
  - Recognize the JXR extension
  - Changed wording of IPTC "Unrecognized data" warning
  - Patched round-off error problem in seconds of some date/time values
  - Fixed problem creating EXV files with the -o option
  - Fixed problem conditionally replacing Extra block-type tags
  Feb. 17, 2014 - Version 9.52
  - Fixed bug introduced in 9.44 which resulted in incorrect maker note offsets
    when copying maker notes from DNG images of some Pentax models
  Feb. 15, 2014 - Version 9.51
  - Added a number of new CanonModelID values
  - Added a new Sony/Minolta LensType (thanks Jos Roost)
  - Added a new Panasonic BurstMode
  - Added a new Pentax LensType
  - Added new ColorSpaceTags shortcut
  - Decode a number of new PanasonicRaw tags (thanks LibRaw)
  - Decode ColorData tags for the new Canon EOS 1200D
  - Improved Sony maker note decoding for some newer models (thanks Jos Roost)
  - Fixed conversion of XMP:LensID for Pentax lenses on Ricoh-branded cameras
  Feb. 8, 2014 - Version 9.50
  - Added support for Exiv2 EXV metadata files
  - Added ability to read/write/copy GeoTiff tags as a block
  - Added ability to combine -b with -j to write base64-encoded binary data in
    JSON output format
  - Added a new Nikon LensID
  - Added a new Sony/Minolta LensType (thanks Jos Roost)
  - Added new Extra ProcessingTime tag
  - Added a new Olympus CameraType
  - Added header signature to .EXIF files
  - Decode a new Olympus tag (thanks LibRaw)
  - Improved conversion of some Canon RecordMode values
  - Improved decoding of tags for Hasselblad Stellar (thanks Jos Roost)
  - Fixed -htmlDump offsets for information extracted from some embedded images
  - Fixed hemisphere problem in Composite GPS tags derived from
    QuickTime:LocationInformation
  - API Changes:
  - Option names are now case insensitive
  Feb. 1, 2014 - Version 9.49
  - Added new Olympus and Samsung LensType values, and fixed an Olympus lens
    name (thanks Niels Kristian Bech Jensen)
  - Added another Polish tag translation (thanks Kacper Perschke)
  - Added a new Panasonic ColorEffect value
  - Decode a new FujiFilm tag (thanks LibRaw)
  - Adjusted scaling factor for H264 ExposureTime values (thanks Francois)
  .... see Changes for more
* Mon Aug  5 2013 jengelh@inai.de
- Update to new upstream release 9.34
  * Support for many new tag values and marker note formats
  * Added the ability to delete unknown JPEG APP segments by
  segment name
  * Added read support for FLIR FFF and FPF images and decode more
  FLIR tags
  * Added write support for DNG version 1.4 images
  * Added append feature to -w (-w+) and ability to overwrite plus
  append output files (-w+!)
  * Added support for Sigma X3F version 3.0 images
  * Added -W (-tagOut) and -Wext (-tagOutExt) options to allow
  multiple tags to be extracted to separate output files from a
  single source file
- Trim excessive description; remove redundant %%clean section
* Mon Mar 25 2013 Greg.Freemyer@gmail.com
- Update to Version 9.13 (production release)
  - Added ability to read FileInodeChangeDate (non-Windows only)
  - API Changes:
  - Enhanced SetFileModifyDate() to write FileCreateDate (Windows only)
  - Added RequestAll option
  - Fixed problem in SetNewValue when setting the Raw value of some tags
  - Enhanced GetValue() to allow return of 'Rational' value
  - Numerous device support and other improvements - see Changes file
* Sat Sep 29 2012 Greg.Freemyer@gmail.com
- add perl-File-RandomAccess sub-package to match package in graphics
- remove stale comments about doc files
* Mon Sep 24 2012 Greg.Freemyer@gmail.com
- Ran spec-cleaner
- Added conflicts: exiftool < %%{version} to perl-Image-ExifTool so that if the module is upgraded, the app will be too
- Upgrade to v9.01  (Production Release)
  - Numerous new metadata fields added
  - see http://owl.phy.queensu.ca/~phil/exiftool/history.html
  - Changed -restore_original and -delete_original options to scan directories only for writable file types
  - Enhanced -srcfile option to allow multiple source files to be specified
  - API Changes:
  Added GlobalTimeShift option
  Added NoFlat option to SetNewValues()
  Changed Struct option to allow copying of both structured and flattened tags at the same time
  Added XMPAutoConv option
* Tue Mar  6 2012 Greg.Freemyer@gmail.com
- Upgrade to v8.77
  Added *.args and *.fmt convenience files to the %%doc section.  These files have apparently been
  in the tarball for a while, but not in the %%doc section as they should have been.
  This package has been rapidly seeing small releases.  There have been 12 releases since it was last updated
  for openSUSE12.1 in Sept. 2011.  Afew of the key updates are below.  See the Changes file in doc directory,
  or http://cpansearch.perl.org/src/EXIFTOOL/Image-ExifTool-8.77/Changes
  * Highlights of Changes for Versions 8.66 to 8.77
  - IMPORTANT: Fixed bug which could corrupt GIF images when writing a Comment
  to a GIF image containing XMP metadata
  API Changes:
  Added Sort2 option and 'Descr' setting for Sort option
  Added secondary sort option to GetFoundTags() and GetTagList()
  Changed name of Sort 'Alpha' setting to 'Tag' (but 'Alpha' still works for backward compatibility)
  - Enhanced SetNewValue() AddValue option to allow this option to be ignored for non-list tags
  - Added ProtectSaved option to SetNewValue() and return save count from SaveNewValues()
  - Added CharsetEXIF and CharsetQuickTime options
* Mon Dec 12 2011 Greg.Freemyer@gmail.com
- clean up requires around perl(IO::Compress).  It was previously wrong.
* Mon Sep 26 2011 Greg.Freemyer@gmail.com
- update to 8.65
  * /usr/bin/exiftool was previously packaged as only an application and the perl(Image::ExifTool) module was not available for use.
  * Thus the standalone exiftool package has now been obsoleted
  * And /usr/bin/exiftool is now included in this package as a sub-package in addition to the perl library modules
  * 
  * A significant number of new file formats, etc. are now supported, see
  * http://cpansearch.perl.org/src/EXIFTOOL/Image-ExifTool-8.65/Changes
* Mon Feb 21 2011 Greg.Freemyer@gmail.com
- initial package 8.40
  * created by cpanspec 1.78.03
